# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clientmetrics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63lientmetrics.proto\"\x8e\x02\n*CClientMetrics_ClientBootstrap_RequestInfo\x12\x19\n\x11original_hostname\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x63tual_hostname\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x11\n\tbase_name\x18\x04 \x01(\t\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12\x13\n\x0bstatus_code\x18\x06 \x01(\r\x12\x1e\n\x16\x61\x64\x64ress_of_request_url\x18\x07 \x01(\t\x12\x18\n\x10response_time_ms\x18\x08 \x01(\r\x12\x16\n\x0e\x62ytes_received\x18\t \x01(\x04\x12\x13\n\x0bnum_retries\x18\n \x01(\r\"\xa9\x02\n&CClientMetrics_ClientBootstrap_Summary\x12\x15\n\rlauncher_type\x18\x01 \x01(\r\x12\x13\n\x0bsteam_realm\x18\x02 \x01(\r\x12\x11\n\tbeta_name\x18\x03 \x01(\t\x12\x1a\n\x12\x64ownload_completed\x18\x04 \x01(\x08\x12\x15\n\rtotal_time_ms\x18\x06 \x01(\r\x12\x46\n\x11manifest_requests\x18\x07 \x03(\x0b\x32+.CClientMetrics_ClientBootstrap_RequestInfo\x12\x45\n\x10package_requests\x18\x08 \x03(\x0b\x32+.CClientMetrics_ClientBootstrap_RequestInfo\"\xba\x01\n-CClientMetrics_ContentDownloadResponse_Counts\x12\x11\n\tclass_100\x18\x01 \x01(\r\x12\x11\n\tclass_200\x18\x02 \x01(\r\x12\x11\n\tclass_300\x18\x03 \x01(\r\x12\x11\n\tclass_400\x18\x04 \x01(\r\x12\x11\n\tclass_500\x18\x05 \x01(\r\x12\x13\n\x0bno_response\x18\x06 \x01(\r\x12\x15\n\rclass_unknown\x18\x07 \x01(\r\"\x9a\x01\n1CClientMetrics_ContentDownloadResponse_HostCounts\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x13\n\x0bsource_type\x18\x02 \x01(\r\x12>\n\x06\x63ounts\x18\x03 \x01(\x0b\x32..CClientMetrics_ContentDownloadResponse_Counts\"q\n,CClientMetrics_ContentDownloadResponse_Hosts\x12\x41\n\x05hosts\x18\x01 \x03(\x0b\x32\x32.CClientMetrics_ContentDownloadResponse_HostCountsB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'clientmetrics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_REQUESTINFO._serialized_start=24
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_REQUESTINFO._serialized_end=294
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_SUMMARY._serialized_start=297
  _CCLIENTMETRICS_CLIENTBOOTSTRAP_SUMMARY._serialized_end=594
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_COUNTS._serialized_start=597
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_COUNTS._serialized_end=783
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTCOUNTS._serialized_start=786
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTCOUNTS._serialized_end=940
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTS._serialized_start=942
  _CCLIENTMETRICS_CONTENTDOWNLOADRESPONSE_HOSTS._serialized_end=1055
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_gamerecordingfiles.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2
import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&webuimessages_gamerecordingfiles.proto\x1a\x0b\x65nums.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"\xbc\x01\n\x12\x43GameRecordingFile\x12\x32\n\ttimelines\x18\x01 \x03(\x0b\x32\x1f.CGameRecordingTimelineMetadata\x12\x37\n\x0fpostgame_events\x18\x02 \x03(\x0b\x32\x1e.CGameRecordingPostGameSummary\x12\x17\n\x0ftemporary_clips\x18\x03 \x03(\t\x12 \n\x04tags\x18\x04 \x03(\x0b\x32\x12.CGameRecordingTag\"\xc1\x03\n\x16\x43GameRecordingClipFile\x12\x32\n\ttimelines\x18\x01 \x03(\x0b\x32\x1f.CGameRecordingTimelineMetadata\x12&\n\x1e\x66irst_timeline_start_offset_ms\x18\x02 \x01(\x04\x12\x15\n\rdate_recorded\x18\x03 \x01(\r\x12\x0f\n\x07game_id\x18\x04 \x01(\x04\x12\x19\n\x11published_file_id\x18\x05 \x01(\x06\x12\x15\n\rsize_in_bytes\x18\x06 \x01(\x04\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x11\n\ttemporary\x18\x08 \x01(\x08\x12\x17\n\x0foriginal_device\x18\t \x01(\t\x12#\n\x1boriginal_gaming_device_type\x18\n \x01(\r\x12\x17\n\x0f\x64\x61te_downloaded\x18\x0b \x01(\r\x12\x17\n\x0fthumbnail_width\x18\x0c \x01(\r\x12\x18\n\x10thumbnail_height\x18\r \x01(\r\x12 \n\x04tags\x18\x0e \x03(\x0b\x32\x12.CGameRecordingTag\x12$\n\x06phases\x18\x0f \x03(\x0b\x32\x14.CGameRecordingPhase\"\xe0\x04\n\x1e\x43GameRecordingTimelineMetadata\x12\x13\n\x0btimeline_id\x18\x01 \x01(\t\x12\x0f\n\x07game_id\x18\x02 \x01(\x04\x12\x15\n\rdate_recorded\x18\x03 \x01(\r\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\x04\x12=\n\nrecordings\x18\x05 \x03(\x0b\x32).CGameRecordingTimelineMetadata.Recording\x12$\n\x06phases\x18\x06 \x03(\x0b\x32\x14.CGameRecordingPhase\x12\x38\n\x12significant_events\x18\x07 \x03(\x0b\x32\x1c.CGameRecordingTimelineEvent\x1a\xcc\x02\n\tRecording\x12\x14\n\x0crecording_id\x18\x01 \x01(\t\x12\x17\n\x0fstart_offset_ms\x18\x02 \x01(\x04\x12\x13\n\x0b\x64uration_ms\x18\x03 \x01(\x04\x12I\n\x0erecording_type\x18\x04 \x01(\x0e\x32\x13.EGameRecordingType:\x1ck_EGameRecordingType_Unknown\x12\x19\n\x11\x64\x65lete_on_cleanup\x18\x05 \x01(\x08\x12\x1d\n\x15video_manager_clip_id\x18\x06 \x01(\x04\x12\x1e\n\x16video_manager_video_id\x18\x07 \x01(\x04\x12\x18\n\x10\x63\x64n_manifest_url\x18\x08 \x01(\t\x12\x11\n\tfile_size\x18\t \x01(\x04\x12)\n!recording_zero_timeline_offset_ms\x18\n \x01(\x04\"^\n\x1d\x43GameRecordingPostGameSummary\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12,\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x1c.CGameRecordingTimelineEvent\"\xf1\x01\n\x1b\x43GameRecordingTimelineEvent\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x12\n\nrt_created\x18\x02 \x01(\r\x12\x15\n\rpossible_clip\x18\x03 \x01(\x05\x12\x13\n\x0btimeline_id\x18\x04 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x05 \x01(\x04\x12\x1a\n\x12timeline_offset_ms\x18\x06 \x01(\x04\x12\x13\n\x0b\x64uration_ms\x18\x07 \x01(\x04\x12\x13\n\x0bmarker_icon\x18\x08 \x01(\t\x12\x14\n\x0cmarker_title\x18\t \x01(\t\x12\x13\n\x0buser_marker\x18\n \x01(\x08\"\xb6\x01\n\x11\x43GameRecordingTag\x12\x0f\n\x07game_id\x18\x01 \x01(\x04\x12\x1a\n\x03tag\x18\x02 \x01(\x0b\x32\r.CTimelineTag\x12/\n\nreferences\x18\x03 \x03(\x0b\x32\x1b.CGameRecordingTag.Timeline\x1a\x43\n\x08Timeline\x12\x0f\n\x07\x63lip_id\x18\x01 \x01(\t\x12\x13\n\x0btimeline_id\x18\x02 \x01(\t\x12\x11\n\toffset_ms\x18\x03 \x01(\x04\"s\n\x19\x43GameRecordingTagInstance\x12\x13\n\x0btimeline_id\x18\x01 \x01(\t\x12\x10\n\x08\x65ntry_id\x18\x02 \x01(\x04\x12\x1a\n\x12timeline_offset_ms\x18\x03 \x01(\x04\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\x04\"\x84\x02\n\x13\x43GameRecordingPhase\x12\x10\n\x08phase_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\x04\x12&\n\x04tags\x18\x06 \x03(\x0b\x32\x18.CGameRecordingPhase.Tag\x12\x30\n\x0e\x63ontained_tags\x18\x07 \x03(\x0b\x32\x18.CGameRecordingPhase.Tag\x12\"\n\x1a\x62\x61\x63kground_timeline_offset\x18\x08 \x01(\x04\x12$\n\nattributes\x18\t \x03(\x0b\x32\x10.CPhaseAttribute\x1a\"\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\"K\n\x0c\x43TimelineTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\r\"A\n\x0f\x43PhaseAttribute\x12\r\n\x05group\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\rB\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_gamerecordingfiles_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _CGAMERECORDINGFILE._serialized_start=108
  _CGAMERECORDINGFILE._serialized_end=296
  _CGAMERECORDINGCLIPFILE._serialized_start=299
  _CGAMERECORDINGCLIPFILE._serialized_end=748
  _CGAMERECORDINGTIMELINEMETADATA._serialized_start=751
  _CGAMERECORDINGTIMELINEMETADATA._serialized_end=1359
  _CGAMERECORDINGTIMELINEMETADATA_RECORDING._serialized_start=1027
  _CGAMERECORDINGTIMELINEMETADATA_RECORDING._serialized_end=1359
  _CGAMERECORDINGPOSTGAMESUMMARY._serialized_start=1361
  _CGAMERECORDINGPOSTGAMESUMMARY._serialized_end=1455
  _CGAMERECORDINGTIMELINEEVENT._serialized_start=1458
  _CGAMERECORDINGTIMELINEEVENT._serialized_end=1699
  _CGAMERECORDINGTAG._serialized_start=1702
  _CGAMERECORDINGTAG._serialized_end=1884
  _CGAMERECORDINGTAG_TIMELINE._serialized_start=1817
  _CGAMERECORDINGTAG_TIMELINE._serialized_end=1884
  _CGAMERECORDINGTAGINSTANCE._serialized_start=1886
  _CGAMERECORDINGTAGINSTANCE._serialized_end=2001
  _CGAMERECORDINGPHASE._serialized_start=2004
  _CGAMERECORDINGPHASE._serialized_end=2264
  _CGAMERECORDINGPHASE_TAG._serialized_start=2230
  _CGAMERECORDINGPHASE_TAG._serialized_end=2264
  _CTIMELINETAG._serialized_start=2266
  _CTIMELINETAG._serialized_end=2341
  _CPHASEATTRIBUTE._serialized_start=2343
  _CPHASEATTRIBUTE._serialized_end=2408
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_video.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&steammessages_clientserver_video.proto\x1a\x18steammessages_base.proto\"\xc1\x02\n$CMsgVideoGameRecordingRepresentation\x12\x1b\n\x13representation_name\x18\x02 \x01(\t\x12\x1d\n\x15horizontal_resolution\x18\x03 \x01(\r\x12\x1b\n\x13vertical_resolution\x18\x04 \x01(\r\x12\x12\n\nframe_rate\x18\x05 \x01(\x01\x12\x11\n\tbandwidth\x18\x06 \x01(\r\x12\x19\n\x11\x61udio_sample_rate\x18\x07 \x01(\r\x12\x19\n\x11\x66rame_rate_string\x18\x08 \x01(\t\x12\r\n\x05\x63odec\x18\t \x01(\t\x12\x1c\n\x14\x61udio_channel_config\x18\n \x01(\r\x12\x36\n\x0csegment_info\x18\x0b \x03(\x0b\x32 .CVideo_GameRecordingSegmentInfo\"\xb4\x01\n\x1f\x43MsgVideoGameRecordingComponent\x12\x16\n\x0e\x63omponent_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ontents\x18\x02 \x01(\r\x12\x14\n\x0csegment_size\x18\x03 \x01(\r\x12\x11\n\tfile_type\x18\x04 \x01(\t\x12>\n\x0frepresentations\x18\x05 \x03(\x0b\x32%.CMsgVideoGameRecordingRepresentation\"\x9f\x02\n\x19\x43MsgVideoGameRecordingDef\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x14\n\x0cnum_segments\x18\x03 \x01(\r\x12\x1b\n\x13length_milliseconds\x18\x04 \x01(\r\x12\"\n\x1asegment_duration_timescale\x18\x05 \x01(\r\x12\x18\n\x10segment_duration\x18\x06 \x01(\r\x12\x34\n\ncomponents\x18\x07 \x03(\x0b\x32 .CMsgVideoGameRecordingComponent\x12\x15\n\rstart_time_ms\x18\x08 \x01(\r\x12#\n\x1bstart_offset_in_timeline_ms\x18\t \x01(\r\"\x8a\x01\n\x1f\x43Video_GameRecordingSegmentInfo\x12\x16\n\x0esegment_number\x18\x01 \x01(\r\x12\x1a\n\x12segment_size_bytes\x18\x02 \x01(\x04\x12\x16\n\x0e\x63omponent_name\x18\x03 \x01(\t\x12\x1b\n\x13representation_name\x18\x04 \x01(\t\"\x8f\x02\n%CVideo_GameRecordingSegmentUploadInfo\x12\x36\n\x0csegment_info\x18\x01 \x01(\x0b\x32 .CVideo_GameRecordingSegmentInfo\x12\x10\n\x08url_host\x18\x02 \x01(\t\x12\x10\n\x08url_path\x18\x03 \x01(\t\x12\x11\n\tuse_https\x18\x04 \x01(\x08\x12K\n\x0frequest_headers\x18\x05 \x03(\x0b\x32\x32.CVideo_GameRecordingSegmentUploadInfo.HTTPHeaders\x1a*\n\x0bHTTPHeaders\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_video_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGVIDEOGAMERECORDINGREPRESENTATION._serialized_start=69
  _CMSGVIDEOGAMERECORDINGREPRESENTATION._serialized_end=390
  _CMSGVIDEOGAMERECORDINGCOMPONENT._serialized_start=393
  _CMSGVIDEOGAMERECORDINGCOMPONENT._serialized_end=573
  _CMSGVIDEOGAMERECORDINGDEF._serialized_start=576
  _CMSGVIDEOGAMERECORDINGDEF._serialized_end=863
  _CVIDEO_GAMERECORDINGSEGMENTINFO._serialized_start=866
  _CVIDEO_GAMERECORDINGSEGMENTINFO._serialized_end=1004
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO._serialized_start=1007
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO._serialized_end=1278
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO_HTTPHEADERS._serialized_start=1236
  _CVIDEO_GAMERECORDINGSEGMENTUPLOADINFO_HTTPHEADERS._serialized_end=1278
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_childprocessquery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steammessages_childprocessquery.proto\x1a\x0b\x65nums.proto\"f\n\x1d\x43MsgChildProcessQueryResponse\x12\x39\n\x0cgpu_topology\x18\x01 \x01(\x0b\x32!.CMsgChildProcessQueryGpuTopologyH\x00\x42\n\n\x08response\"\xd4\x02\n CMsgChildProcessQueryGpuTopology\x12\x37\n\x04gpus\x18\x01 \x03(\x0b\x32).CMsgChildProcessQueryGpuTopology.GpuInfo\x12\x16\n\x0e\x64\x65\x66\x61ult_gpu_id\x18\x02 \x01(\r\x1a\xde\x01\n\x07GpuInfo\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fvram_size_bytes\x18\x03 \x01(\x04\x12\x38\n\tdriver_id\x18\x04 \x01(\x0e\x32\r.EGpuDriverId:\x16k_EGpuDriverId_Invalid\x12\x1c\n\x14\x64river_version_major\x18\x05 \x01(\x05\x12\x1c\n\x14\x64river_version_minor\x18\x06 \x01(\x05\x12\x1c\n\x14\x64river_version_patch\x18\x07 \x01(\x05\x12\x0c\n\x04luid\x18\x08 \x01(\x04\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_childprocessquery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCHILDPROCESSQUERYRESPONSE._serialized_start=54
  _CMSGCHILDPROCESSQUERYRESPONSE._serialized_end=156
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY._serialized_start=159
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY._serialized_end=499
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY_GPUINFO._serialized_start=277
  _CMSGCHILDPROCESSQUERYGPUTOPOLOGY_GPUINFO._serialized_end=499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_accounthardware.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#steammessages_accounthardware.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"b\n0CAccountHardware_RegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"3\n1CAccountHardware_RegisterSteamController_Response\"n\n<CAccountHardware_CompleteSteamControllerRegistration_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"?\n=CAccountHardware_CompleteSteamControllerRegistration_Response\"j\n8CAccountHardware_QueryAccountsRegisteredToSerial_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"m\n9CAccountHardware_QueryAccountsRegisteredToSerial_Accounts\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x1d\n\x15registration_complete\x18\x02 \x01(\x08\"\x89\x01\n9CAccountHardware_QueryAccountsRegisteredToSerial_Response\x12L\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32:.CAccountHardware_QueryAccountsRegisteredToSerial_Accounts\"\xcb\x01\n4CAccountHardware_UpdateControllerUsageReport_Request\x12U\n\x0b\x63ontrollers\x18\x01 \x03(\x0b\x32@.CAccountHardware_UpdateControllerUsageReport_Request.Controller\x1a<\n\nController\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"7\n5CAccountHardware_UpdateControllerUsageReport_Response\"\x80\x01\n:CAccountHardware_SteamControllerSetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\"\x8c\x02\n1CAccountHardware_SteamControllerSetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12S\n\x0e\x63onfigurations\x18\x04 \x03(\x0b\x32;.CAccountHardware_SteamControllerSetConfig_ControllerConfig\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"4\n2CAccountHardware_SteamControllerSetConfig_Response\"\xcc\x01\n1CAccountHardware_SteamControllerGetConfig_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\x12\x13\n\x0b\x61ppidorname\x18\x04 \x01(\t\x12\x1a\n\x0f\x63ontroller_type\x18\x05 \x01(\x05:\x01\x32\x12#\n\x14only_for_this_serial\x18\x06 \x01(\x08:\x05\x66\x61lse\"\xb0\x01\n:CAccountHardware_SteamControllerGetConfig_ControllerConfig\x12\x13\n\x0b\x61ppidorname\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x14\n\x0ctemplatename\x18\x03 \x01(\t\x12\x15\n\rserial_number\x18\x04 \x01(\t\x12\x17\n\x08\x61utosave\x18\x05 \x01(\x08:\x05\x66\x61lse\"\x89\x01\n2CAccountHardware_SteamControllerGetConfig_Response\x12S\n\x0e\x63onfigurations\x18\x01 \x03(\x0b\x32;.CAccountHardware_SteamControllerGetConfig_ControllerConfig\"w\n2CAccountHardware_DeRegisterSteamController_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\x12\x11\n\taccountid\x18\x03 \x01(\r\"5\n3CAccountHardware_DeRegisterSteamController_Response\"t\n/CAccountHardware_SetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0fpublishedfileid\x18\x02 \x01(\x04\x12\x11\n\taccountid\x18\x03 \x01(\r\"2\n0CAccountHardware_SetPersonalizationFile_Response\"[\n/CAccountHardware_GetPersonalizationFile_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x11\n\taccountid\x18\x02 \x01(\r\"K\n0CAccountHardware_GetPersonalizationFile_Response\x12\x17\n\x0fpublishedfileid\x18\x01 \x01(\x04\"\xae\x01\n-CAccountHardware_VRCompatibilityCheck_Request\x12\x14\n\x0cproduct_name\x18\x01 \x01(\t\x12\x43\n\x06values\x18\x02 \x03(\x0b\x32\x33.CAccountHardware_VRCompatibilityCheck_Request.Pair\x1a\"\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xb0\x02\n.CAccountHardware_VRCompatibilityCheck_Response\x12\x44\n\x06values\x18\x01 \x03(\x0b\x32\x34.CAccountHardware_VRCompatibilityCheck_Response.Pair\x12T\n\ncomponents\x18\x02 \x03(\x0b\x32@.CAccountHardware_VRCompatibilityCheck_Response.ComponentDisplay\x1a\"\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a>\n\x10\x43omponentDisplay\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfa\x01\n4CAccountHardware_RegisterValveIndexComponent_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\"\n\x1amanufacturer_serial_number\x18\x02 \x01(\t\x12\x16\n\x0e\x63omponent_code\x18\x03 \x01(\t\x12L\n\x0e\x63omponent_type\x18\x04 \x01(\x0e\x32\x15.EValveIndexComponent:\x1dk_EValveIndexComponentUnknown\x12!\n\x19\x65stimated_time_registered\x18\x05 \x01(\x05\"7\n5CAccountHardware_RegisterValveIndexComponent_Response\"a\n/CAccountHardware_GetSteamDeckComponents_Request\x12\x15\n\rserial_number\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontroller_code\x18\x02 \x01(\t\"K\n0CAccountHardware_GetSteamDeckComponents_Response\x12\x17\n\x0fjson_components\x18\x01 \x01(\t*\xdd\x01\n\x14\x45ValveIndexComponent\x12!\n\x1dk_EValveIndexComponentUnknown\x10\x00\x12\x1d\n\x19k_EValveIndexComponentHMD\x10\x01\x12%\n!k_EValveIndexComponentLeftKnuckle\x10\x02\x12&\n\"k_EValveIndexComponentRightKnuckle\x10\x03\x12\x10\n\x0ck_ETempDTst1\x10\x04\x12\x10\n\x0ck_ETempDTst2\x10\x05\x12\x10\n\x0ck_ETempDTst3\x10\x06\x32\xa9\r\n\x0f\x41\x63\x63ountHardware\x12\x80\x01\n\x17RegisterSteamController\x12\x31.CAccountHardware_RegisterSteamController_Request\x1a\x32.CAccountHardware_RegisterSteamController_Response\x12\xa4\x01\n#CompleteSteamControllerRegistration\x12=.CAccountHardware_CompleteSteamControllerRegistration_Request\x1a>.CAccountHardware_CompleteSteamControllerRegistration_Response\x12\x9c\x01\n#QueryAccountsRegisteredToController\x12\x39.CAccountHardware_QueryAccountsRegisteredToSerial_Request\x1a:.CAccountHardware_QueryAccountsRegisteredToSerial_Response\x12\x8c\x01\n\x1bUpdateControllerUsageReport\x12\x35.CAccountHardware_UpdateControllerUsageReport_Request\x1a\x36.CAccountHardware_UpdateControllerUsageReport_Response\x12\x8b\x01\n SetDesiredControllerConfigForApp\x12\x32.CAccountHardware_SteamControllerSetConfig_Request\x1a\x33.CAccountHardware_SteamControllerSetConfig_Response\x12\x8b\x01\n GetDesiredControllerConfigForApp\x12\x32.CAccountHardware_SteamControllerGetConfig_Request\x1a\x33.CAccountHardware_SteamControllerGetConfig_Response\x12\x86\x01\n\x19\x44\x65RegisterSteamController\x12\x33.CAccountHardware_DeRegisterSteamController_Request\x1a\x34.CAccountHardware_DeRegisterSteamController_Response\x12\x87\x01\n SetControllerPersonalizationFile\x12\x30.CAccountHardware_SetPersonalizationFile_Request\x1a\x31.CAccountHardware_SetPersonalizationFile_Response\x12\x87\x01\n GetControllerPersonalizationFile\x12\x30.CAccountHardware_GetPersonalizationFile_Request\x1a\x31.CAccountHardware_GetPersonalizationFile_Response\x12w\n\x14VRCompatibilityCheck\x12..CAccountHardware_VRCompatibilityCheck_Request\x1a/.CAccountHardware_VRCompatibilityCheck_Response\x12\x8c\x01\n\x1bRegisterValveIndexComponent\x12\x35.CAccountHardware_RegisterValveIndexComponent_Request\x1a\x36.CAccountHardware_RegisterValveIndexComponent_Response\x12}\n\x16GetSteamDeckComponents\x12\x30.CAccountHardware_GetSteamDeckComponents_Request\x1a\x31.CAccountHardware_GetSteamDeckComponents_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_accounthardware_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _EVALVEINDEXCOMPONENT._serialized_start=3520
  _EVALVEINDEXCOMPONENT._serialized_end=3741
  _CACCOUNTHARDWARE_REGISTERSTEAMCONTROLLER_REQUEST._serialized_start=99
  _CACCOUNTHARDWARE_REGISTERSTEAMCONTROLLER_REQUEST._serialized_end=197
  _CACCOUNTHARDWARE_REGISTERSTEAMCONTROLLER_RESPONSE._serialized_start=199
  _CACCOUNTHARDWARE_REGISTERSTEAMCONTROLLER_RESPONSE._serialized_end=250
  _CACCOUNTHARDWARE_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST._serialized_start=252
  _CACCOUNTHARDWARE_COMPLETESTEAMCONTROLLERREGISTRATION_REQUEST._serialized_end=362
  _CACCOUNTHARDWARE_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE._serialized_start=364
  _CACCOUNTHARDWARE_COMPLETESTEAMCONTROLLERREGISTRATION_RESPONSE._serialized_end=427
  _CACCOUNTHARDWARE_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST._serialized_start=429
  _CACCOUNTHARDWARE_QUERYACCOUNTSREGISTEREDTOSERIAL_REQUEST._serialized_end=535
  _CACCOUNTHARDWARE_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS._serialized_start=537
  _CACCOUNTHARDWARE_QUERYACCOUNTSREGISTEREDTOSERIAL_ACCOUNTS._serialized_end=646
  _CACCOUNTHARDWARE_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE._serialized_start=649
  _CACCOUNTHARDWARE_QUERYACCOUNTSREGISTEREDTOSERIAL_RESPONSE._serialized_end=786
  _CACCOUNTHARDWARE_UPDATECONTROLLERUSAGEREPORT_REQUEST._serialized_start=789
  _CACCOUNTHARDWARE_UPDATECONTROLLERUSAGEREPORT_REQUEST._serialized_end=992
  _CACCOUNTHARDWARE_UPDATECONTROLLERUSAGEREPORT_REQUEST_CONTROLLER._serialized_start=932
  _CACCOUNTHARDWARE_UPDATECONTROLLERUSAGEREPORT_REQUEST_CONTROLLER._serialized_end=992
  _CACCOUNTHARDWARE_UPDATECONTROLLERUSAGEREPORT_RESPONSE._serialized_start=994
  _CACCOUNTHARDWARE_UPDATECONTROLLERUSAGEREPORT_RESPONSE._serialized_end=1049
  _CACCOUNTHARDWARE_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG._serialized_start=1052
  _CACCOUNTHARDWARE_STEAMCONTROLLERSETCONFIG_CONTROLLERCONFIG._serialized_end=1180
  _CACCOUNTHARDWARE_STEAMCONTROLLERSETCONFIG_REQUEST._serialized_start=1183
  _CACCOUNTHARDWARE_STEAMCONTROLLERSETCONFIG_REQUEST._serialized_end=1451
  _CACCOUNTHARDWARE_STEAMCONTROLLERSETCONFIG_RESPONSE._serialized_start=1453
  _CACCOUNTHARDWARE_STEAMCONTROLLERSETCONFIG_RESPONSE._serialized_end=1505
  _CACCOUNTHARDWARE_STEAMCONTROLLERGETCONFIG_REQUEST._serialized_start=1508
  _CACCOUNTHARDWARE_STEAMCONTROLLERGETCONFIG_REQUEST._serialized_end=1712
  _CACCOUNTHARDWARE_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG._serialized_start=1715
  _CACCOUNTHARDWARE_STEAMCONTROLLERGETCONFIG_CONTROLLERCONFIG._serialized_end=1891
  _CACCOUNTHARDWARE_STEAMCONTROLLERGETCONFIG_RESPONSE._serialized_start=1894
  _CACCOUNTHARDWARE_STEAMCONTROLLERGETCONFIG_RESPONSE._serialized_end=2031
  _CACCOUNTHARDWARE_DEREGISTERSTEAMCONTROLLER_REQUEST._serialized_start=2033
  _CACCOUNTHARDWARE_DEREGISTERSTEAMCONTROLLER_REQUEST._serialized_end=2152
  _CACCOUNTHARDWARE_DEREGISTERSTEAMCONTROLLER_RESPONSE._serialized_start=2154
  _CACCOUNTHARDWARE_DEREGISTERSTEAMCONTROLLER_RESPONSE._serialized_end=2207
  _CACCOUNTHARDWARE_SETPERSONALIZATIONFILE_REQUEST._serialized_start=2209
  _CACCOUNTHARDWARE_SETPERSONALIZATIONFILE_REQUEST._serialized_end=2325
  _CACCOUNTHARDWARE_SETPERSONALIZATIONFILE_RESPONSE._serialized_start=2327
  _CACCOUNTHARDWARE_SETPERSONALIZATIONFILE_RESPONSE._serialized_end=2377
  _CACCOUNTHARDWARE_GETPERSONALIZATIONFILE_REQUEST._serialized_start=2379
  _CACCOUNTHARDWARE_GETPERSONALIZATIONFILE_REQUEST._serialized_end=2470
  _CACCOUNTHARDWARE_GETPERSONALIZATIONFILE_RESPONSE._serialized_start=2472
  _CACCOUNTHARDWARE_GETPERSONALIZATIONFILE_RESPONSE._serialized_end=2547
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_REQUEST._serialized_start=2550
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_REQUEST._serialized_end=2724
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_REQUEST_PAIR._serialized_start=2690
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_REQUEST_PAIR._serialized_end=2724
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_RESPONSE._serialized_start=2727
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_RESPONSE._serialized_end=3031
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_RESPONSE_PAIR._serialized_start=2690
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_RESPONSE_PAIR._serialized_end=2724
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_RESPONSE_COMPONENTDISPLAY._serialized_start=2969
  _CACCOUNTHARDWARE_VRCOMPATIBILITYCHECK_RESPONSE_COMPONENTDISPLAY._serialized_end=3031
  _CACCOUNTHARDWARE_REGISTERVALVEINDEXCOMPONENT_REQUEST._serialized_start=3034
  _CACCOUNTHARDWARE_REGISTERVALVEINDEXCOMPONENT_REQUEST._serialized_end=3284
  _CACCOUNTHARDWARE_REGISTERVALVEINDEXCOMPONENT_RESPONSE._serialized_start=3286
  _CACCOUNTHARDWARE_REGISTERVALVEINDEXCOMPONENT_RESPONSE._serialized_end=3341
  _CACCOUNTHARDWARE_GETSTEAMDECKCOMPONENTS_REQUEST._serialized_start=3343
  _CACCOUNTHARDWARE_GETSTEAMDECKCOMPONENTS_REQUEST._serialized_end=3440
  _CACCOUNTHARDWARE_GETSTEAMDECKCOMPONENTS_RESPONSE._serialized_start=3442
  _CACCOUNTHARDWARE_GETSTEAMDECKCOMPONENTS_RESPONSE._serialized_end=3517
  _ACCOUNTHARDWARE._serialized_start=3744
  _ACCOUNTHARDWARE._serialized_end=5449
_builder.BuildServices(DESCRIPTOR, 'steammessages_accounthardware_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_ucm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_clientserver_ucm.proto\x1a\x18steammessages_base.proto\"\x81\x03\n\x1a\x43MsgClientUCMAddScreenshot\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x11\n\tthumbname\x18\x03 \x01(\t\x12\x13\n\x0bvr_filename\x18\x0e \x01(\t\x12\x17\n\x0frtime32_created\x18\x04 \x01(\x07\x12\r\n\x05width\x18\x05 \x01(\r\x12\x0e\n\x06height\x18\x06 \x01(\r\x12\x13\n\x0bpermissions\x18\x07 \x01(\r\x12\x0f\n\x07\x63\x61ption\x18\x08 \x01(\t\x12\x15\n\rshortcut_name\x18\t \x01(\t\x12,\n\x03tag\x18\n \x03(\x0b\x32\x1f.CMsgClientUCMAddScreenshot.Tag\x12\x16\n\x0etagged_steamid\x18\x0b \x03(\x06\x12\x13\n\x0bspoiler_tag\x18\x0c \x01(\x08\x12\x1e\n\x16tagged_publishedfileid\x18\r \x03(\x04\x1a*\n\x03Tag\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x11\n\ttag_value\x18\x02 \x01(\t\"}\n\"CMsgClientUCMAddScreenshotResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12*\n\x0cscreenshotid\x18\x02 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x17\n\x0fpublishedfileid\x18\x03 \x01(\x04\"K\n\x1d\x43MsgClientUCMDeleteScreenshot\x12*\n\x0cscreenshotid\x18\x01 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\";\n%CMsgClientUCMDeleteScreenshotResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"\xd1\x02\n\x18\x43MsgClientUCMPublishFile\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x19\n\x11preview_file_name\x18\x03 \x01(\t\x12\x17\n\x0f\x63onsumer_app_id\x18\x04 \x01(\r\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x08 \x03(\t\x12\x15\n\rworkshop_file\x18\t \x01(\x08\x12\x12\n\nvisibility\x18\n \x01(\x05\x12\x11\n\tfile_type\x18\x0b \x01(\r\x12\x0b\n\x03url\x18\x0c \x01(\t\x12\x16\n\x0evideo_provider\x18\r \x01(\r\x12\x1a\n\x12video_account_name\x18\x0e \x01(\t\x12\x18\n\x10video_identifier\x18\x0f \x01(\t\x12\x13\n\x0bin_progress\x18\x10 \x01(\x08\"\xa1\x01\n CMsgClientUCMPublishFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12/\n\x11published_file_id\x18\x02 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x38\n)needs_workshop_legal_agreement_acceptance\x18\x03 \x01(\x08:\x05\x66\x61lse\"\xf0\x08\n CMsgClientUCMUpdatePublishedFile\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x19\n\x11published_file_id\x18\x02 \x01(\x06\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12\x19\n\x11preview_file_name\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\x12\n\nvisibility\x18\x08 \x01(\x05\x12\x13\n\x0bupdate_file\x18\t \x01(\x08\x12\x1b\n\x13update_preview_file\x18\n \x01(\x08\x12\x14\n\x0cupdate_title\x18\x0b \x01(\x08\x12\x1a\n\x12update_description\x18\x0c \x01(\x08\x12\x13\n\x0bupdate_tags\x18\r \x01(\x08\x12\x19\n\x11update_visibility\x18\x0e \x01(\x08\x12\x1a\n\x12\x63hange_description\x18\x0f \x01(\t\x12\x12\n\nupdate_url\x18\x10 \x01(\x08\x12\x0b\n\x03url\x18\x11 \x01(\t\x12\x1f\n\x17update_content_manifest\x18\x12 \x01(\x08\x12\x18\n\x10\x63ontent_manifest\x18\x13 \x01(\x06\x12\x10\n\x08metadata\x18\x14 \x01(\t\x12\x17\n\x0fupdate_metadata\x18\x15 \x01(\x08\x12\x13\n\x08language\x18\x16 \x01(\x05:\x01\x30\x12\x16\n\x0eremoved_kvtags\x18\x17 \x03(\t\x12=\n\x06kvtags\x18\x18 \x03(\x0b\x32-.CMsgClientUCMUpdatePublishedFile.KeyValueTag\x12\x45\n\x08previews\x18\x19 \x03(\x0b\x32\x33.CMsgClientUCMUpdatePublishedFile.AdditionalPreview\x12\x1a\n\x12previews_to_remove\x18\x1a \x03(\x05\x12\x19\n\x11\x63lear_in_progress\x18\x1b \x01(\x08\x12\x19\n\x11remove_all_kvtags\x18\x1c \x01(\x08\x12\"\n\x1a\x63ontent_descriptors_to_add\x18\x1d \x03(\x05\x12%\n\x1d\x63ontent_descriptors_to_remove\x18\x1e \x03(\x05\x12\x1f\n\x10\x61llow_admin_tags\x18\x1f \x01(\x08:\x05\x66\x61lse\x12\x19\n\x11\x65xternal_asset_id\x18  \x01(\x04\x12\x17\n\x0fgame_branch_min\x18! \x01(\t\x12\x17\n\x0fgame_branch_max\x18\" \x01(\t\x1a)\n\x0bKeyValueTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x8c\x01\n\x11\x41\x64\x64itionalPreview\x12\x1a\n\x12original_file_name\x18\x01 \x01(\t\x12\x1a\n\x12internal_file_name\x18\x02 \x01(\t\x12\x0f\n\x07videoid\x18\x03 \x01(\t\x12\x14\n\x0cpreview_type\x18\x04 \x01(\r\x12\x18\n\x0cupdate_index\x18\x05 \x01(\x05:\x02-1\"x\n(CMsgClientUCMUpdatePublishedFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x38\n)needs_workshop_legal_agreement_acceptance\x18\x02 \x01(\x08:\x05\x66\x61lse\"M\n CMsgClientUCMDeletePublishedFile\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\">\n(CMsgClientUCMDeletePublishedFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"\x8c\x01\n4CMsgClientUCMEnumerateUserSubscribedFilesWithUpdates\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x12\n\nstart_time\x18\x03 \x01(\x07\x12\x1b\n\x10\x64\x65sired_revision\x18\x04 \x01(\r:\x01\x30\"\xe4\x04\n<CMsgClientUCMEnumerateUserSubscribedFilesWithUpdatesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12g\n\x10subscribed_files\x18\x02 \x03(\x0b\x32M.CMsgClientUCMEnumerateUserSubscribedFilesWithUpdatesResponse.PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\x1ai\n\x0e\x41uthorSnapshot\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\x17\n\x0fgame_branch_min\x18\x02 \x01(\t\x12\x17\n\x0fgame_branch_max\x18\x03 \x01(\t\x12\x12\n\nmanifestid\x18\x04 \x01(\x06\x1a\xa4\x02\n\x0fPublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x1d\n\x12rtime32_subscribed\x18\x02 \x01(\x07:\x01\x30\x12\r\n\x05\x61ppid\x18\x03 \x01(\r\x12\x15\n\rfile_hcontent\x18\x04 \x01(\x06\x12\x11\n\tfile_size\x18\x05 \x01(\r\x12\x1c\n\x14rtime32_last_updated\x18\x06 \x01(\x07\x12\x18\n\x10is_depot_content\x18\x07 \x01(\x08\x12\x66\n\x10\x61uthor_snapshots\x18\x08 \x03(\x0b\x32L.CMsgClientUCMEnumerateUserSubscribedFilesWithUpdatesResponse.AuthorSnapshot\"\xb5\x01\n!CMsgClientUCMPublishedFileUpdated\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x14\n\x0ctime_updated\x18\x03 \x01(\r\x12\x10\n\x08hcontent\x18\x04 \x01(\x06\x12\x11\n\tfile_size\x18\x05 \x01(\x07\x12\x18\n\x10is_depot_content\x18\x06 \x01(\x08\x12\x10\n\x08revision\x18\x07 \x01(\r\"k\n$CMsgClientWorkshopItemChangesRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x19\n\x11last_time_updated\x18\x02 \x01(\r\x12\x18\n\x10num_items_needed\x18\x03 \x01(\r\"\xfb\x01\n%CMsgClientWorkshopItemChangesResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x13\n\x0bupdate_time\x18\x02 \x01(\r\x12O\n\x0eworkshop_items\x18\x05 \x03(\x0b\x32\x37.CMsgClientWorkshopItemChangesResponse.WorkshopItemInfo\x1aX\n\x10WorkshopItemInfo\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x14\n\x0ctime_updated\x18\x02 \x01(\r\x12\x13\n\x0bmanifest_id\x18\x03 \x01(\x06\"d\n\'CMsgClientUCMSetUserPublishedFileAction\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\"E\n/CMsgClientUCMSetUserPublishedFileActionResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"g\n0CMsgClientUCMEnumeratePublishedFilesByUserAction\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0bstart_index\x18\x02 \x01(\r\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\"\x94\x02\n8CMsgClientUCMEnumeratePublishedFilesByUserActionResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x62\n\x0fpublished_files\x18\x02 \x03(\x0b\x32I.CMsgClientUCMEnumeratePublishedFilesByUserActionResponse.PublishedFileId\x12\x15\n\rtotal_results\x18\x03 \x01(\r\x1aI\n\x0fPublishedFileId\x12\x19\n\x11published_file_id\x18\x01 \x01(\x06\x12\x1b\n\x10rtime_time_stamp\x18\x02 \x01(\x07:\x01\x30\"\x1e\n\x1c\x43MsgClientScreenshotsChangedB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_ucm_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTUCMADDSCREENSHOT._serialized_start=67
  _CMSGCLIENTUCMADDSCREENSHOT._serialized_end=452
  _CMSGCLIENTUCMADDSCREENSHOT_TAG._serialized_start=410
  _CMSGCLIENTUCMADDSCREENSHOT_TAG._serialized_end=452
  _CMSGCLIENTUCMADDSCREENSHOTRESPONSE._serialized_start=454
  _CMSGCLIENTUCMADDSCREENSHOTRESPONSE._serialized_end=579
  _CMSGCLIENTUCMDELETESCREENSHOT._serialized_start=581
  _CMSGCLIENTUCMDELETESCREENSHOT._serialized_end=656
  _CMSGCLIENTUCMDELETESCREENSHOTRESPONSE._serialized_start=658
  _CMSGCLIENTUCMDELETESCREENSHOTRESPONSE._serialized_end=717
  _CMSGCLIENTUCMPUBLISHFILE._serialized_start=720
  _CMSGCLIENTUCMPUBLISHFILE._serialized_end=1057
  _CMSGCLIENTUCMPUBLISHFILERESPONSE._serialized_start=1060
  _CMSGCLIENTUCMPUBLISHFILERESPONSE._serialized_end=1221
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILE._serialized_start=1224
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILE._serialized_end=2360
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILE_KEYVALUETAG._serialized_start=2176
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILE_KEYVALUETAG._serialized_end=2217
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILE_ADDITIONALPREVIEW._serialized_start=2220
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILE_ADDITIONALPREVIEW._serialized_end=2360
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILERESPONSE._serialized_start=2362
  _CMSGCLIENTUCMUPDATEPUBLISHEDFILERESPONSE._serialized_end=2482
  _CMSGCLIENTUCMDELETEPUBLISHEDFILE._serialized_start=2484
  _CMSGCLIENTUCMDELETEPUBLISHEDFILE._serialized_end=2561
  _CMSGCLIENTUCMDELETEPUBLISHEDFILERESPONSE._serialized_start=2563
  _CMSGCLIENTUCMDELETEPUBLISHEDFILERESPONSE._serialized_end=2625
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATES._serialized_start=2628
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATES._serialized_end=2768
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATESRESPONSE._serialized_start=2771
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATESRESPONSE._serialized_end=3383
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATESRESPONSE_AUTHORSNAPSHOT._serialized_start=2983
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATESRESPONSE_AUTHORSNAPSHOT._serialized_end=3088
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATESRESPONSE_PUBLISHEDFILEID._serialized_start=3091
  _CMSGCLIENTUCMENUMERATEUSERSUBSCRIBEDFILESWITHUPDATESRESPONSE_PUBLISHEDFILEID._serialized_end=3383
  _CMSGCLIENTUCMPUBLISHEDFILEUPDATED._serialized_start=3386
  _CMSGCLIENTUCMPUBLISHEDFILEUPDATED._serialized_end=3567
  _CMSGCLIENTWORKSHOPITEMCHANGESREQUEST._serialized_start=3569
  _CMSGCLIENTWORKSHOPITEMCHANGESREQUEST._serialized_end=3676
  _CMSGCLIENTWORKSHOPITEMCHANGESRESPONSE._serialized_start=3679
  _CMSGCLIENTWORKSHOPITEMCHANGESRESPONSE._serialized_end=3930
  _CMSGCLIENTWORKSHOPITEMCHANGESRESPONSE_WORKSHOPITEMINFO._serialized_start=3842
  _CMSGCLIENTWORKSHOPITEMCHANGESRESPONSE_WORKSHOPITEMINFO._serialized_end=3930
  _CMSGCLIENTUCMSETUSERPUBLISHEDFILEACTION._serialized_start=3932
  _CMSGCLIENTUCMSETUSERPUBLISHEDFILEACTION._serialized_end=4032
  _CMSGCLIENTUCMSETUSERPUBLISHEDFILEACTIONRESPONSE._serialized_start=4034
  _CMSGCLIENTUCMSETUSERPUBLISHEDFILEACTIONRESPONSE._serialized_end=4103
  _CMSGCLIENTUCMENUMERATEPUBLISHEDFILESBYUSERACTION._serialized_start=4105
  _CMSGCLIENTUCMENUMERATEPUBLISHEDFILESBYUSERACTION._serialized_end=4208
  _CMSGCLIENTUCMENUMERATEPUBLISHEDFILESBYUSERACTIONRESPONSE._serialized_start=4211
  _CMSGCLIENTUCMENUMERATEPUBLISHEDFILESBYUSERACTIONRESPONSE._serialized_end=4487
  _CMSGCLIENTUCMENUMERATEPUBLISHEDFILESBYUSERACTIONRESPONSE_PUBLISHEDFILEID._serialized_start=4414
  _CMSGCLIENTUCMENUMERATEPUBLISHEDFILESBYUSERACTIONRESPONSE_PUBLISHEDFILEID._serialized_end=4487
  _CMSGCLIENTSCREENSHOTSCHANGED._serialized_start=4489
  _CMSGCLIENTSCREENSHOTSCHANGED._serialized_end=4519
# @@protoc_insertion_point(module_scope)




import sys

def versions_report():
    """Print a report of al dependacy versions, and environment"""

    from steam import __version__
    print("steam: {}".format(__version__))

    # dependecy versions
    print("\nDependencies:")

    import pkg_resources

    installed_pkgs = {pkg.project_name.lower(): pkg.version for pkg in pkg_resources.working_set}

    for dep in [
                "vdf",
                "protobuf",
                "requests",
                "cachetools",
                "gevent",
                "gevent-eventemitter",
                "pycryptodomex",
                "enum34",
                "win-inet-pton",
                ]:
        print("{:>20}: {}".format(dep, installed_pkgs.get(dep.lower(), "Not Installed")))

    # python runtime
    print("\nPython runtime:")
    print("          executable: %s" % sys.executable)
    print("             version: %s" % sys.version.replace('\n', ''))
    print("            platform: %s" % sys.platform)

    # system info
    import platform

    print("\nSystem info:")
    print("              system: %s" % platform.system())
    print("             machine: %s" % platform.machine())
    print("             release: %s" % platform.release())
    print("             version: %s" % platform.version())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: webuimessages_achievements.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.webuimessages_base_pb2 as webuimessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n webuimessages_achievements.proto\x1a\x18steammessages_base.proto\x1a\x18webuimessages_base.proto\"/\n\x1d\x43\x41\x63hievements_GetInfo_Request\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\"\xf0\x01\n\x1e\x43\x41\x63hievements_GetInfo_Response\x12:\n\x0c\x61\x63hievements\x18\x01 \x03(\x0b\x32$.CAchievements_GetInfo_Response.Info\x1a\x91\x01\n\x04Info\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\x1a\n\x12image_url_achieved\x18\x04 \x01(\t\x12\x1e\n\x16image_url_not_achieved\x18\x05 \x01(\t\x12\x10\n\x08\x61\x63hieved\x18\x06 \x01(\x08\x12\x13\n\x0bunlock_time\x18\x07 \x01(\r2`\n\x0c\x41\x63hievements\x12J\n\x07GetInfo\x12\x1e.CAchievements_GetInfo_Request\x1a\x1f.CAchievements_GetInfo_Response\x1a\x04\x80\x97\"\x02\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'webuimessages_achievements_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _ACHIEVEMENTS._options = None
  _ACHIEVEMENTS._serialized_options = b'\200\227\"\002'
  _CACHIEVEMENTS_GETINFO_REQUEST._serialized_start=88
  _CACHIEVEMENTS_GETINFO_REQUEST._serialized_end=135
  _CACHIEVEMENTS_GETINFO_RESPONSE._serialized_start=138
  _CACHIEVEMENTS_GETINFO_RESPONSE._serialized_end=378
  _CACHIEVEMENTS_GETINFO_RESPONSE_INFO._serialized_start=233
  _CACHIEVEMENTS_GETINFO_RESPONSE_INFO._serialized_end=378
  _ACHIEVEMENTS._serialized_start=380
  _ACHIEVEMENTS._serialized_end=476
_builder.BuildServices(DESCRIPTOR, 'webuimessages_achievements_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18steammessages_base.proto\x1a google/protobuf/descriptor.proto\"1\n\rCMsgIPAddress\x12\x0c\n\x02v4\x18\x01 \x01(\x07H\x00\x12\x0c\n\x02v6\x18\x02 \x01(\x0cH\x00\x42\x04\n\x02ip\"R\n\x13\x43MsgIPAddressBucket\x12+\n\x13original_ip_address\x18\x01 \x01(\x0b\x32\x0e.CMsgIPAddress\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\x06\"O\n\x1b\x43MsgGCRoutingProtoBufHeader\x12\x16\n\x0e\x64st_gcid_queue\x18\x01 \x01(\x04\x12\x18\n\x10\x64st_gc_dir_index\x18\x02 \x01(\r\"\xed\x08\n\x12\x43MsgProtoBufHeader\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10\x63lient_sessionid\x18\x02 \x01(\x05\x12\x15\n\rrouting_appid\x18\x03 \x01(\r\x12*\n\x0cjobid_source\x18\n \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12*\n\x0cjobid_target\x18\x0b \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x17\n\x0ftarget_job_name\x18\x0c \x01(\t\x12\x0f\n\x07seq_num\x18\x18 \x01(\x05\x12\x12\n\x07\x65result\x18\r \x01(\x05:\x01\x32\x12\x15\n\rerror_message\x18\x0e \x01(\t\x12\x1a\n\x12\x61uth_account_flags\x18\x10 \x01(\r\x12\x14\n\x0ctoken_source\x18\x16 \x01(\r\x12\x1b\n\x13\x61\x64min_spoofing_user\x18\x17 \x01(\x08\x12\x1a\n\x0ftransport_error\x18\x11 \x01(\x05:\x01\x31\x12\'\n\tmessageid\x18\x12 \x01(\x04:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x1a\n\x12publisher_group_id\x18\x13 \x01(\r\x12\r\n\x05sysid\x18\x14 \x01(\r\x12\x15\n\rwebapi_key_id\x18\x19 \x01(\r\x12\x1f\n\x17is_from_external_source\x18\x1a \x01(\x08\x12\x18\n\x10\x66orward_to_sysid\x18\x1b \x03(\r\x12\x10\n\x08\x63m_sysid\x18\x1c \x01(\r\x12\x18\n\rlauncher_type\x18\x1f \x01(\r:\x01\x30\x12\x10\n\x05realm\x18  \x01(\r:\x01\x30\x12\x16\n\ntimeout_ms\x18! \x01(\x05:\x02-1\x12\x14\n\x0c\x64\x65\x62ug_source\x18\" \x01(\t\x12!\n\x19\x64\x65\x62ug_source_string_index\x18# \x01(\r\x12\x10\n\x08token_id\x18$ \x01(\x04\x12\x30\n\nrouting_gc\x18% \x01(\x0b\x32\x1c.CMsgGCRoutingProtoBufHeader\x12\x61\n\x13session_disposition\x18& \x01(\x0e\x32\'.CMsgProtoBufHeader.ESessionDisposition:\x1bk_ESessionDispositionNormal\x12\x10\n\x08wg_token\x18\' \x01(\t\x12\x16\n\x0ewebui_auth_key\x18( \x01(\t\x12!\n\x19\x65xclude_client_sessionids\x18) \x03(\x05\x12&\n\x1e\x61\x64min_request_spoofing_steamid\x18+ \x01(\x06\x12\x12\n\nis_valveds\x18, \x01(\x08\x12\x11\n\ttrace_tag\x18- \x01(\x06\x12\x0c\n\x02ip\x18\x0f \x01(\rH\x00\x12\x0f\n\x05ip_v6\x18\x1d \x01(\x0cH\x00\"[\n\x13\x45SessionDisposition\x12\x1f\n\x1bk_ESessionDispositionNormal\x10\x00\x12#\n\x1fk_ESessionDispositionDisconnect\x10\x01\x42\t\n\x07ip_addr\"\x84\x02\n\x11\x43MsgKubeRPCPacket\x12#\n\x03hdr\x18\x01 \x01(\x0b\x32\x16.CMsgKubeRPCPacket.Hdr\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x1a\xb8\x01\n\x03Hdr\x12*\n\x0cjobid_source\x18\n \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12*\n\x0cjobid_target\x18\x0b \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x12\n\x07\x65result\x18\r \x01(\x05:\x01\x32\x12\x17\n\x0ftarget_job_name\x18\x0c \x01(\t\x12\x15\n\rerror_message\x18\x0e \x01(\t\x12\x15\n\rreply_address\x18* \x01(\t\"8\n\tCMsgMulti\x12\x15\n\rsize_unzipped\x18\x01 \x01(\r\x12\x14\n\x0cmessage_body\x18\x02 \x01(\x0c\"+\n\x13\x43MsgProtobufWrapped\x12\x14\n\x0cmessage_body\x18\x01 \x01(\x0c\"\xbb\x01\n\x0e\x43MsgAuthTicket\x12\x0e\n\x06\x65state\x18\x01 \x01(\r\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12\x0f\n\x07steamid\x18\x03 \x01(\x06\x12\x0e\n\x06gameid\x18\x04 \x01(\x06\x12\x14\n\x0ch_steam_pipe\x18\x05 \x01(\r\x12\x12\n\nticket_crc\x18\x06 \x01(\r\x12\x0e\n\x06ticket\x18\x07 \x01(\x0c\x12\x15\n\rserver_secret\x18\x08 \x01(\x0c\x12\x13\n\x0bticket_type\x18\t \x01(\r\"\x98\x03\n\x14\x43\x43\x44\x44\x42\x41ppDetailCommon\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x0c\n\x04tool\x18\x06 \x01(\x08\x12\x0c\n\x04\x64\x65mo\x18\x07 \x01(\x08\x12\r\n\x05media\x18\x08 \x01(\x08\x12\x1f\n\x17\x63ommunity_visible_stats\x18\t \x01(\x08\x12\x15\n\rfriendly_name\x18\n \x01(\t\x12\x13\n\x0bpropagation\x18\x0b \x01(\t\x12\x19\n\x11has_adult_content\x18\x0c \x01(\x08\x12!\n\x19is_visible_in_steam_china\x18\r \x01(\x08\x12\x10\n\x08\x61pp_type\x18\x0e \x01(\r\x12\x1d\n\x15has_adult_content_sex\x18\x0f \x01(\x08\x12\"\n\x1ahas_adult_content_violence\x18\x10 \x01(\x08\x12\x1d\n\x15\x63ontent_descriptorids\x18\x11 \x03(\r\x12+\n#content_descriptorids_including_dlc\x18\x12 \x03(\r\"\xb3\x03\n\rCMsgAppRights\x12\x11\n\tedit_info\x18\x01 \x01(\x08\x12\x0f\n\x07publish\x18\x02 \x01(\x08\x12\x17\n\x0fview_error_data\x18\x03 \x01(\x08\x12\x10\n\x08\x64ownload\x18\x04 \x01(\x08\x12\x15\n\rupload_cdkeys\x18\x05 \x01(\x08\x12\x17\n\x0fgenerate_cdkeys\x18\x06 \x01(\x08\x12\x17\n\x0fview_financials\x18\x07 \x01(\x08\x12\x12\n\nmanage_ceg\x18\x08 \x01(\x08\x12\x16\n\x0emanage_signing\x18\t \x01(\x08\x12\x15\n\rmanage_cdkeys\x18\n \x01(\x08\x12\x16\n\x0e\x65\x64it_marketing\x18\x0b \x01(\x08\x12\x17\n\x0f\x65\x63onomy_support\x18\x0c \x01(\x08\x12\"\n\x1a\x65\x63onomy_support_supervisor\x18\r \x01(\x08\x12\x16\n\x0emanage_pricing\x18\x0e \x01(\x08\x12\x16\n\x0e\x62roadcast_live\x18\x0f \x01(\x08\x12\x1e\n\x16view_marketing_traffic\x18\x10 \x01(\x08\x12\"\n\x1a\x65\x64it_store_display_content\x18\x11 \x01(\x08\"\xf1\x02\n\x13\x43\x43uratorPreferences\x12\x1b\n\x13supported_languages\x18\x01 \x01(\r\x12\x18\n\x10platform_windows\x18\x02 \x01(\x08\x12\x14\n\x0cplatform_mac\x18\x03 \x01(\x08\x12\x16\n\x0eplatform_linux\x18\x04 \x01(\x08\x12\x12\n\nvr_content\x18\x05 \x01(\x08\x12\x1e\n\x16\x61\x64ult_content_violence\x18\x06 \x01(\x08\x12\x19\n\x11\x61\x64ult_content_sex\x18\x07 \x01(\x08\x12\x19\n\x11timestamp_updated\x18\x08 \x01(\r\x12\x16\n\x0etagids_curated\x18\t \x03(\r\x12\x17\n\x0ftagids_filtered\x18\n \x03(\r\x12\x15\n\rwebsite_title\x18\x0b \x01(\t\x12\x13\n\x0bwebsite_url\x18\x0c \x01(\t\x12\x16\n\x0e\x64iscussion_url\x18\r \x01(\t\x12\x16\n\x0eshow_broadcast\x18\x0e \x01(\x08\"@\n\x12\x43LocalizationToken\x12\x10\n\x08language\x18\x01 \x01(\r\x12\x18\n\x10localized_string\x18\x02 \x01(\t\"\xec\x01\n\x17\x43\x43lanEventUserNewsTuple\x12\x0e\n\x06\x63lanid\x18\x01 \x01(\r\x12\x11\n\tevent_gid\x18\x02 \x01(\x06\x12\x18\n\x10\x61nnouncement_gid\x18\x03 \x01(\x06\x12\x13\n\x0brtime_start\x18\x04 \x01(\r\x12\x11\n\trtime_end\x18\x05 \x01(\r\x12\x16\n\x0epriority_score\x18\x06 \x01(\r\x12\x0c\n\x04type\x18\x07 \x01(\r\x12\x18\n\x10\x63lamp_range_slot\x18\x08 \x01(\r\x12\r\n\x05\x61ppid\x18\t \x01(\r\x12\x1d\n\x15rtime32_last_modified\x18\n \x01(\r\"\x80\x01\n\x16\x43\x43lanMatchEventByRange\x12\x14\n\x0crtime_before\x18\x01 \x01(\r\x12\x13\n\x0brtime_after\x18\x02 \x01(\r\x12\x11\n\tqualified\x18\x03 \x01(\r\x12(\n\x06\x65vents\x18\x04 \x03(\x0b\x32\x18.CClanEventUserNewsTuple\"\x9b\x03\n\x1f\x43\x43ommunity_ClanAnnouncementInfo\x12\x0b\n\x03gid\x18\x01 \x01(\x04\x12\x0e\n\x06\x63lanid\x18\x02 \x01(\x04\x12\x10\n\x08posterid\x18\x03 \x01(\x04\x12\x10\n\x08headline\x18\x04 \x01(\t\x12\x10\n\x08posttime\x18\x05 \x01(\r\x12\x12\n\nupdatetime\x18\x06 \x01(\r\x12\x0c\n\x04\x62ody\x18\x07 \x01(\t\x12\x14\n\x0c\x63ommentcount\x18\x08 \x01(\x05\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x10\n\x08language\x18\n \x01(\x05\x12\x0e\n\x06hidden\x18\x0b \x01(\x08\x12\x16\n\x0e\x66orum_topic_id\x18\x0c \x01(\x06\x12\x11\n\tevent_gid\x18\r \x01(\x06\x12\x13\n\x0bvoteupcount\x18\x0e \x01(\x05\x12\x15\n\rvotedowncount\x18\x0f \x01(\x05\x12V\n\x10\x62\x61n_check_result\x18\x10 \x01(\x0e\x32\x17.EBanContentCheckResult:#k_EBanContentCheckResult_NotScanned\x12\x0e\n\x06\x62\x61nned\x18\x11 \x01(\x08\"\xb8\x06\n\x0e\x43\x43lanEventData\x12\x0b\n\x03gid\x18\x01 \x01(\x06\x12\x14\n\x0c\x63lan_steamid\x18\x02 \x01(\x06\x12\x12\n\nevent_name\x18\x03 \x01(\t\x12;\n\nevent_type\x18\x04 \x01(\x0e\x32\x14.EProtoClanEventType:\x11k_EClanOtherEvent\x12\r\n\x05\x61ppid\x18\x05 \x01(\r\x12\x16\n\x0eserver_address\x18\x06 \x01(\t\x12\x17\n\x0fserver_password\x18\x07 \x01(\t\x12\x1a\n\x12rtime32_start_time\x18\x08 \x01(\r\x12\x18\n\x10rtime32_end_time\x18\t \x01(\r\x12\x15\n\rcomment_count\x18\n \x01(\x05\x12\x17\n\x0f\x63reator_steamid\x18\x0b \x01(\x06\x12\x1b\n\x13last_update_steamid\x18\x0c \x01(\x06\x12\x13\n\x0b\x65vent_notes\x18\r \x01(\t\x12\x10\n\x08jsondata\x18\x0e \x01(\t\x12;\n\x11\x61nnouncement_body\x18\x0f \x01(\x0b\x32 .CCommunity_ClanAnnouncementInfo\x12\x11\n\tpublished\x18\x10 \x01(\x08\x12\x0e\n\x06hidden\x18\x11 \x01(\x08\x12 \n\x18rtime32_visibility_start\x18\x12 \x01(\r\x12\x1e\n\x16rtime32_visibility_end\x18\x13 \x01(\r\x12\x1d\n\x15\x62roadcaster_accountid\x18\x14 \x01(\r\x12\x16\n\x0e\x66ollower_count\x18\x15 \x01(\r\x12\x14\n\x0cignore_count\x18\x16 \x01(\r\x12\x16\n\x0e\x66orum_topic_id\x18\x17 \x01(\x06\x12\x1d\n\x15rtime32_last_modified\x18\x18 \x01(\r\x12\x15\n\rnews_post_gid\x18\x19 \x01(\x06\x12\x1a\n\x12rtime_mod_reviewed\x18\x1a \x01(\r\x12\x1a\n\x12\x66\x65\x61tured_app_tagid\x18\x1b \x01(\r\x12\x19\n\x11referenced_appids\x18\x1c \x03(\r\x12\x10\n\x08\x62uild_id\x18\x1d \x01(\r\x12\x14\n\x0c\x62uild_branch\x18\x1e \x01(\t\x12\x10\n\x08unlisted\x18\x1f \x01(\x08\"\xc7\x01\n\x10\x43\x42illing_Address\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\x10\n\x08\x61\x64\x64ress1\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64\x64ress2\x18\x04 \x01(\t\x12\x0c\n\x04\x63ity\x18\x05 \x01(\t\x12\x10\n\x08us_state\x18\x06 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x07 \x01(\t\x12\x10\n\x08postcode\x18\x08 \x01(\t\x12\x11\n\tzip_plus4\x18\t \x01(\x05\x12\r\n\x05phone\x18\n \x01(\t\"\x9c\x02\n\x19\x43PackageReservationStatus\x12\x11\n\tpackageid\x18\x01 \x01(\r\x12\x19\n\x11reservation_state\x18\x02 \x01(\x05\x12\x16\n\x0equeue_position\x18\x03 \x01(\x05\x12\x18\n\x10total_queue_size\x18\x04 \x01(\x05\x12 \n\x18reservation_country_code\x18\x05 \x01(\t\x12\x0f\n\x07\x65xpired\x18\x06 \x01(\x08\x12\x14\n\x0ctime_expires\x18\x07 \x01(\r\x12\x15\n\rtime_reserved\x18\x08 \x01(\r\x12$\n\x1crtime_estimated_notification\x18\t \x01(\r\x12\x19\n\x11notificaton_token\x18\n \x01(\t\"/\n\x10\x43MsgKeyValuePair\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"3\n\x0f\x43MsgKeyValueSet\x12 \n\x05pairs\x18\x01 \x03(\x0b\x32\x11.CMsgKeyValuePair\"\xcb\x01\n UserContentDescriptorPreferences\x12[\n\x1e\x63ontent_descriptors_to_exclude\x18\x01 \x03(\x0b\x32\x33.UserContentDescriptorPreferences.ContentDescriptor\x1aJ\n\x11\x43ontentDescriptor\x12\x1c\n\x14\x63ontent_descriptorid\x18\x01 \x01(\r\x12\x17\n\x0ftimestamp_added\x18\x02 \x01(\r*\xd8\x02\n\x16\x45\x42\x61nContentCheckResult\x12\'\n#k_EBanContentCheckResult_NotScanned\x10\x00\x12\"\n\x1ek_EBanContentCheckResult_Reset\x10\x01\x12*\n&k_EBanContentCheckResult_NeedsChecking\x10\x02\x12)\n%k_EBanContentCheckResult_VeryUnlikely\x10\x05\x12%\n!k_EBanContentCheckResult_Unlikely\x10\x1e\x12%\n!k_EBanContentCheckResult_Possible\x10\x32\x12#\n\x1fk_EBanContentCheckResult_Likely\x10K\x12\'\n#k_EBanContentCheckResult_VeryLikely\x10\x64*\xeb\x07\n\x13\x45ProtoClanEventType\x12\x15\n\x11k_EClanOtherEvent\x10\x01\x12\x14\n\x10k_EClanGameEvent\x10\x02\x12\x15\n\x11k_EClanPartyEvent\x10\x03\x12\x17\n\x13k_EClanMeetingEvent\x10\x04\x12\x1c\n\x18k_EClanSpecialCauseEvent\x10\x05\x12\x1c\n\x18k_EClanMusicAndArtsEvent\x10\x06\x12\x16\n\x12k_EClanSportsEvent\x10\x07\x12\x14\n\x10k_EClanTripEvent\x10\x08\x12\x14\n\x10k_EClanChatEvent\x10\t\x12\x1b\n\x17k_EClanGameReleaseEvent\x10\n\x12\x19\n\x15k_EClanBroadcastEvent\x10\x0b\x12\x1b\n\x17k_EClanSmallUpdateEvent\x10\x0c\x12&\n\"k_EClanPreAnnounceMajorUpdateEvent\x10\r\x12\x1b\n\x17k_EClanMajorUpdateEvent\x10\x0e\x12\x1a\n\x16k_EClanDLCReleaseEvent\x10\x0f\x12\x1d\n\x19k_EClanFutureReleaseEvent\x10\x10\x12&\n\"k_EClanESportTournamentStreamEvent\x10\x11\x12\x19\n\x15k_EClanDevStreamEvent\x10\x12\x12\x1c\n\x18k_EClanFamousStreamEvent\x10\x13\x12\x19\n\x15k_EClanGameSalesEvent\x10\x14\x12\x1d\n\x19k_EClanGameItemSalesEvent\x10\x15\x12\x1d\n\x19k_EClanInGameBonusXPEvent\x10\x16\x12\x1a\n\x16k_EClanInGameLootEvent\x10\x17\x12\x1b\n\x17k_EClanInGamePerksEvent\x10\x18\x12\x1f\n\x1bk_EClanInGameChallengeEvent\x10\x19\x12\x1d\n\x19k_EClanInGameContestEvent\x10\x1a\x12\x13\n\x0fk_EClanIRLEvent\x10\x1b\x12\x14\n\x10k_EClanNewsEvent\x10\x1c\x12\x1b\n\x17k_EClanBetaReleaseEvent\x10\x1d\x12$\n k_EClanInGameContentReleaseEvent\x10\x1e\x12\x14\n\x10k_EClanFreeTrial\x10\x1f\x12\x18\n\x14k_EClanSeasonRelease\x10 \x12\x17\n\x13k_EClanSeasonUpdate\x10!\x12\x19\n\x15k_EClanCrosspostEvent\x10\"\x12\x1d\n\x19k_EClanInGameEventGeneral\x10#*\x81\x01\n\x1cPartnerEventNotificationType\x12\x11\n\rk_EEventStart\x10\x00\x12\x1a\n\x16k_EEventBroadcastStart\x10\x01\x12\x16\n\x12k_EEventMatchStart\x10\x02\x12\x1a\n\x16k_EEventPartnerMaxType\x10\x03:A\n\x12msgpool_soft_limit\x12\x1f.google.protobuf.MessageOptions\x18\xd0\x86\x03 \x01(\x05:\x02\x33\x32:B\n\x12msgpool_hard_limit\x12\x1f.google.protobuf.MessageOptions\x18\xd1\x86\x03 \x01(\x05:\x03\x33\x38\x34:H\n\x18php_output_always_number\x12\x1d.google.protobuf.FieldOptions\x18\xe4\x86\x03 \x01(\x08:\x05\x66\x61lse:J\n\x1a\x61llow_field_named_steam_id\x12\x1d.google.protobuf.FieldOptions\x18\xe8\x86\x03 \x01(\x08:\x05\x66\x61lseB\x02H\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msgpool_soft_limit)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msgpool_hard_limit)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(php_output_always_number)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(allow_field_named_steam_id)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001'
  _EBANCONTENTCHECKRESULT._serialized_start=5666
  _EBANCONTENTCHECKRESULT._serialized_end=6010
  _EPROTOCLANEVENTTYPE._serialized_start=6013
  _EPROTOCLANEVENTTYPE._serialized_end=7016
  _PARTNEREVENTNOTIFICATIONTYPE._serialized_start=7019
  _PARTNEREVENTNOTIFICATIONTYPE._serialized_end=7148
  _CMSGIPADDRESS._serialized_start=62
  _CMSGIPADDRESS._serialized_end=111
  _CMSGIPADDRESSBUCKET._serialized_start=113
  _CMSGIPADDRESSBUCKET._serialized_end=195
  _CMSGGCROUTINGPROTOBUFHEADER._serialized_start=197
  _CMSGGCROUTINGPROTOBUFHEADER._serialized_end=276
  _CMSGPROTOBUFHEADER._serialized_start=279
  _CMSGPROTOBUFHEADER._serialized_end=1412
  _CMSGPROTOBUFHEADER_ESESSIONDISPOSITION._serialized_start=1310
  _CMSGPROTOBUFHEADER_ESESSIONDISPOSITION._serialized_end=1401
  _CMSGKUBERPCPACKET._serialized_start=1415
  _CMSGKUBERPCPACKET._serialized_end=1675
  _CMSGKUBERPCPACKET_HDR._serialized_start=1491
  _CMSGKUBERPCPACKET_HDR._serialized_end=1675
  _CMSGMULTI._serialized_start=1677
  _CMSGMULTI._serialized_end=1733
  _CMSGPROTOBUFWRAPPED._serialized_start=1735
  _CMSGPROTOBUFWRAPPED._serialized_end=1778
  _CMSGAUTHTICKET._serialized_start=1781
  _CMSGAUTHTICKET._serialized_end=1968
  _CCDDBAPPDETAILCOMMON._serialized_start=1971
  _CCDDBAPPDETAILCOMMON._serialized_end=2379
  _CMSGAPPRIGHTS._serialized_start=2382
  _CMSGAPPRIGHTS._serialized_end=2817
  _CCURATORPREFERENCES._serialized_start=2820
  _CCURATORPREFERENCES._serialized_end=3189
  _CLOCALIZATIONTOKEN._serialized_start=3191
  _CLOCALIZATIONTOKEN._serialized_end=3255
  _CCLANEVENTUSERNEWSTUPLE._serialized_start=3258
  _CCLANEVENTUSERNEWSTUPLE._serialized_end=3494
  _CCLANMATCHEVENTBYRANGE._serialized_start=3497
  _CCLANMATCHEVENTBYRANGE._serialized_end=3625
  _CCOMMUNITY_CLANANNOUNCEMENTINFO._serialized_start=3628
  _CCOMMUNITY_CLANANNOUNCEMENTINFO._serialized_end=4039
  _CCLANEVENTDATA._serialized_start=4042
  _CCLANEVENTDATA._serialized_end=4866
  _CBILLING_ADDRESS._serialized_start=4869
  _CBILLING_ADDRESS._serialized_end=5068
  _CPACKAGERESERVATIONSTATUS._serialized_start=5071
  _CPACKAGERESERVATIONSTATUS._serialized_end=5355
  _CMSGKEYVALUEPAIR._serialized_start=5357
  _CMSGKEYVALUEPAIR._serialized_end=5404
  _CMSGKEYVALUESET._serialized_start=5406
  _CMSGKEYVALUESET._serialized_end=5457
  _USERCONTENTDESCRIPTORPREFERENCES._serialized_start=5460
  _USERCONTENTDESCRIPTORPREFERENCES._serialized_end=5663
  _USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR._serialized_start=5589
  _USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR._serialized_end=5663
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_uds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$steammessages_clientserver_uds.proto\x1a\x18steammessages_base.proto\"G\n\x1e\x43MsgClientUDSP2PSessionStarted\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\"\x81\x02\n\x1c\x43MsgClientUDSP2PSessionEnded\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\x12\x1a\n\x12session_length_sec\x18\x03 \x01(\x05\x12\x15\n\rsession_error\x18\x04 \x01(\x05\x12\x0f\n\x07nattype\x18\x05 \x01(\x05\x12\x12\n\nbytes_recv\x18\x06 \x01(\x05\x12\x12\n\nbytes_sent\x18\x07 \x01(\x05\x12\x18\n\x10\x62ytes_sent_relay\x18\x08 \x01(\x05\x12\x18\n\x10\x62ytes_recv_relay\x18\t \x01(\x05\x12\x1a\n\x12time_to_connect_ms\x18\n \x01(\x05\"\x1c\n\x1a\x43MsgClientGetClientDetails\"\xf0\x02\n\"CMsgClientGetClientDetailsResponse\x12\x17\n\x0fpackage_version\x18\x01 \x01(\r\x12\n\n\x02os\x18\x02 \x01(\t\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12\x11\n\tip_public\x18\x04 \x01(\t\x12\x12\n\nip_private\x18\x05 \x01(\t\x12?\n\rgames_running\x18\x06 \x03(\x0b\x32(.CMsgClientGetClientDetailsResponse.Game\x12\x17\n\x0f\x62ytes_available\x18\x07 \x01(\x04\x12\x18\n\x10protocol_version\x18\x08 \x01(\r\x12\x1a\n\x12\x63lientcomm_version\x18\t \x01(\r\x12\x13\n\x0blocal_users\x18\n \x03(\r\x1a\x43\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nextra_info\x18\x02 \x01(\t\x12\x18\n\x10time_running_sec\x18\x03 \x01(\r\"\xbc\x01\n\x1a\x43MsgClientGetClientAppList\x12\r\n\x05media\x18\x01 \x01(\x08\x12\r\n\x05tools\x18\x02 \x01(\x08\x12\r\n\x05games\x18\x03 \x01(\x08\x12\x16\n\x0eonly_installed\x18\x04 \x01(\x08\x12\x15\n\ronly_changing\x18\x05 \x01(\x08\x12\x0e\n\x06\x63omics\x18\x06 \x01(\x08\x12\x1b\n\x13include_client_info\x18\x07 \x01(\x08\x12\x15\n\rfilter_appids\x18\x08 \x03(\r\"\xcc\x06\n\"CMsgClientGetClientAppListResponse\x12\x35\n\x04\x61pps\x18\x01 \x03(\x0b\x32\'.CMsgClientGetClientAppListResponse.App\x12\x17\n\x0f\x62ytes_available\x18\x02 \x01(\x04\x12\x38\n\x0b\x63lient_info\x18\x03 \x01(\x0b\x32#.CMsgClientGetClientDetailsResponse\x1a\x9b\x05\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_type\x18\n \x01(\t\x12\x10\n\x08\x66\x61vorite\x18\x03 \x01(\x08\x12\x11\n\tinstalled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61uto_update\x18\x05 \x01(\x08\x12\x18\n\x10\x62ytes_downloaded\x18\x06 \x01(\x04\x12\x19\n\x11\x62ytes_to_download\x18\x07 \x01(\x04\x12\x1b\n\x13\x62ytes_download_rate\x18\x08 \x01(\r\x12\x39\n\x04\x64lcs\x18\t \x03(\x0b\x32+.CMsgClientGetClientAppListResponse.App.DLC\x12\x17\n\x0f\x64ownload_paused\x18\x0b \x01(\x08\x12\x17\n\x0fnum_downloading\x18\x0c \x01(\r\x12\x10\n\x08\x63hanging\x18\x0e \x01(\x08\x12\x1d\n\x15\x61vailable_on_platform\x18\x0f \x01(\x08\x12\x14\n\x0c\x62ytes_staged\x18\x10 \x01(\x04\x12\x16\n\x0e\x62ytes_to_stage\x18\x11 \x01(\x04\x12\x16\n\x0e\x62ytes_required\x18\x12 \x01(\x04\x12\x16\n\x0esource_buildid\x18\x13 \x01(\r\x12\x16\n\x0etarget_buildid\x18\x14 \x01(\r\x12#\n\x1b\x65stimated_seconds_remaining\x18\x15 \x01(\r\x12\x16\n\x0equeue_position\x18\x16 \x01(\x05\x12\x14\n\x0cuninstalling\x18\x17 \x01(\x08\x12\x19\n\x11rt_time_scheduled\x18\x18 \x01(\r\x12\x0f\n\x07running\x18\x19 \x01(\x08\x12\x19\n\x11update_percentage\x18\x1a \x01(\r\x1a\'\n\x03\x44LC\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tinstalled\x18\x02 \x01(\x08\"+\n\x1a\x43MsgClientInstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"4\n\"CMsgClientInstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1c\x43MsgClientUninstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"6\n$CMsgClientUninstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"B\n!CMsgClientSetClientAppUpdateState\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06update\x18\x02 \x01(\x08\";\n)CMsgClientSetClientAppUpdateStateResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"\xaa\x01\n\x19\x43MsgClientLaunchClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08language\x18\x02 \x01(\r\x12\x1a\n\x12launch_option_type\x18\x03 \x01(\r\x12\x15\n\rlaunch_option\x18\x04 \x01(\r\x12\x15\n\rlaunch_source\x18\x05 \x01(\r\x12\x0c\n\x04\x61rgs\x18\x06 \x01(\t\x12\x14\n\x0cquery_params\x18\x07 \x01(\t\"3\n!CMsgClientLaunchClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"4\n\"CMsgClientEnableOrDisableDownloads\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"<\n*CMsgClientEnableOrDisableDownloadsResponse\x12\x0e\n\x06result\x18\x01 \x01(\rB\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientserver_uds_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGCLIENTUDSP2PSESSIONSTARTED._serialized_start=66
  _CMSGCLIENTUDSP2PSESSIONSTARTED._serialized_end=137
  _CMSGCLIENTUDSP2PSESSIONENDED._serialized_start=140
  _CMSGCLIENTUDSP2PSESSIONENDED._serialized_end=397
  _CMSGCLIENTGETCLIENTDETAILS._serialized_start=399
  _CMSGCLIENTGETCLIENTDETAILS._serialized_end=427
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE._serialized_start=430
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE._serialized_end=798
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME._serialized_start=731
  _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME._serialized_end=798
  _CMSGCLIENTGETCLIENTAPPLIST._serialized_start=801
  _CMSGCLIENTGETCLIENTAPPLIST._serialized_end=989
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE._serialized_start=992
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE._serialized_end=1836
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP._serialized_start=1169
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP._serialized_end=1836
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC._serialized_start=1797
  _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC._serialized_end=1836
  _CMSGCLIENTINSTALLCLIENTAPP._serialized_start=1838
  _CMSGCLIENTINSTALLCLIENTAPP._serialized_end=1881
  _CMSGCLIENTINSTALLCLIENTAPPRESPONSE._serialized_start=1883
  _CMSGCLIENTINSTALLCLIENTAPPRESPONSE._serialized_end=1935
  _CMSGCLIENTUNINSTALLCLIENTAPP._serialized_start=1937
  _CMSGCLIENTUNINSTALLCLIENTAPP._serialized_end=1982
  _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE._serialized_start=1984
  _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE._serialized_end=2038
  _CMSGCLIENTSETCLIENTAPPUPDATESTATE._serialized_start=2040
  _CMSGCLIENTSETCLIENTAPPUPDATESTATE._serialized_end=2106
  _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE._serialized_start=2108
  _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE._serialized_end=2167
  _CMSGCLIENTLAUNCHCLIENTAPP._serialized_start=2170
  _CMSGCLIENTLAUNCHCLIENTAPP._serialized_end=2340
  _CMSGCLIENTLAUNCHCLIENTAPPRESPONSE._serialized_start=2342
  _CMSGCLIENTLAUNCHCLIENTAPPRESPONSE._serialized_end=2393
  _CMSGCLIENTENABLEORDISABLEDOWNLOADS._serialized_start=2395
  _CMSGCLIENTENABLEORDISABLEDOWNLOADS._serialized_end=2447
  _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE._serialized_start=2449
  _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE._serialized_end=2509
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_parental.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.steammessages_parental_objects_pb2 as steammessages__parental__objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1csteammessages_parental.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a$steammessages_parental_objects.proto\"\x99\x01\n(CParental_EnableParentalSettings_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12#\n\x08settings\x18\x02 \x01(\x0b\x32\x11.ParentalSettings\x12\x11\n\tsessionid\x18\x03 \x01(\t\x12\x12\n\nenablecode\x18\x04 \x01(\r\x12\x0f\n\x07steamid\x18\n \x01(\x06\"+\n)CParental_EnableParentalSettings_Response\"N\n)CParental_DisableParentalSettings_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x0f\n\x07steamid\x18\n \x01(\x06\",\n*CParental_DisableParentalSettings_Response\"8\n%CParental_GetParentalSettings_Request\x12\x0f\n\x07steamid\x18\n \x01(\x06\"M\n&CParental_GetParentalSettings_Response\x12#\n\x08settings\x18\x01 \x01(\x0b\x32\x11.ParentalSettings\"?\n+CParental_GetSignedParentalSettings_Request\x12\x10\n\x08priority\x18\x01 \x01(\r\"^\n,CParental_GetSignedParentalSettings_Response\x12\x1b\n\x13serialized_settings\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"\x98\x01\n%CParental_SetParentalSettings_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12#\n\x08settings\x18\x02 \x01(\x0b\x32\x11.ParentalSettings\x12\x14\n\x0cnew_password\x18\x03 \x01(\t\x12\x11\n\tsessionid\x18\x04 \x01(\t\x12\x0f\n\x07steamid\x18\n \x01(\x06\"(\n&CParental_SetParentalSettings_Response\"7\n\x1f\x43Parental_ValidateToken_Request\x12\x14\n\x0cunlock_token\x18\x01 \x01(\t\"\"\n CParental_ValidateToken_Response\"g\n\"CParental_ValidatePassword_Request\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x0f\n\x07session\x18\x02 \x01(\t\x12\x1e\n\x16send_unlock_on_success\x18\x03 \x01(\x08\"4\n#CParental_ValidatePassword_Response\x12\r\n\x05token\x18\x01 \x01(\t\"/\n\x1c\x43Parental_LockClient_Request\x12\x0f\n\x07session\x18\x01 \x01(\t\"\x1f\n\x1d\x43Parental_LockClient_Response\"\'\n%CParental_RequestRecoveryCode_Request\"(\n&CParental_RequestRecoveryCode_Response\"S\n)CParental_DisableWithRecoveryCode_Request\x12\x15\n\rrecovery_code\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\n \x01(\x06\",\n*CParental_DisableWithRecoveryCode_Response\"K\n&CParental_RequestFeatureAccess_Request\x12\x10\n\x08\x66\x65\x61tures\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\n \x01(\x06\"<\n\'CParental_RequestFeatureAccess_Response\x12\x11\n\trequestid\x18\x01 \x01(\x06\"\x81\x01\n&CParental_ApproveFeatureAccess_Request\x12\x0f\n\x07\x61pprove\x18\x01 \x01(\x08\x12\x11\n\trequestid\x18\x02 \x01(\x06\x12\x10\n\x08\x66\x65\x61tures\x18\x03 \x01(\r\x12\x10\n\x08\x64uration\x18\x04 \x01(\r\x12\x0f\n\x07steamid\x18\n \x01(\x06\")\n\'CParental_ApproveFeatureAccess_Response\"\x87\x01\n!CParental_RequestPlaytime_Request\x12\x14\n\x0ctime_expires\x18\x01 \x01(\r\x12;\n\x1d\x63urrent_playtime_restrictions\x18\x02 \x01(\x0b\x32\x14.ParentalPlaytimeDay\x12\x0f\n\x07steamid\x18\n \x01(\x06\"7\n\"CParental_RequestPlaytime_Response\x12\x11\n\trequestid\x18\x01 \x01(\x06\"\x9f\x01\n!CParental_ApprovePlaytime_Request\x12\x0f\n\x07\x61pprove\x18\x01 \x01(\x08\x12\x11\n\trequestid\x18\x02 \x01(\x06\x12\x45\n\x15restrictions_approved\x18\x03 \x01(\x0b\x32&.ParentalTemporaryPlaytimeRestrictions\x12\x0f\n\x07steamid\x18\n \x01(\x06\"$\n\"CParental_ApprovePlaytime_Response\"[\n\x1d\x43Parental_GetRequests_Request\x12\"\n\x1art_include_completed_since\x18\x01 \x01(\r\x12\x16\n\x0e\x66\x61mily_groupid\x18\x02 \x01(\x06\"\x88\x01\n\x1e\x43Parental_GetRequests_Response\x12\x31\n\x10\x66\x65\x61ture_requests\x18\x01 \x03(\x0b\x32\x17.ParentalFeatureRequest\x12\x33\n\x11playtime_requests\x18\x02 \x03(\x0b\x32\x18.ParentalPlaytimeRequest\"g\n)CParental_ReportPlaytimeAndNotify_Request\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\r\x12\x14\n\x0cminutes_used\x18\x02 \x01(\r\x12\x0f\n\x07steamid\x18\n \x01(\x06\",\n*CParental_ReportPlaytimeAndNotify_Response\"\x84\x01\n-CParental_ParentalSettingsChange_Notification\x12\x1b\n\x13serialized_settings\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x11\n\tsessionid\x18\x04 \x01(\t\"L\n%CParental_ParentalUnlock_Notification\x12\x10\n\x08password\x18\x01 \x01(\t\x12\x11\n\tsessionid\x18\x02 \x01(\t\"8\n#CParental_ParentalLock_Notification\x12\x11\n\tsessionid\x18\x01 \x01(\t\"P\n#CParental_PlaytimeUsed_Notification\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\r\x12\x14\n\x0cminutes_used\x18\x02 \x01(\r2\xe9\x0c\n\x08Parental\x12o\n\x16\x45nableParentalSettings\x12).CParental_EnableParentalSettings_Request\x1a*.CParental_EnableParentalSettings_Response\x12r\n\x17\x44isableParentalSettings\x12*.CParental_DisableParentalSettings_Request\x1a+.CParental_DisableParentalSettings_Response\x12\x66\n\x13GetParentalSettings\x12&.CParental_GetParentalSettings_Request\x1a\'.CParental_GetParentalSettings_Response\x12x\n\x19GetSignedParentalSettings\x12,.CParental_GetSignedParentalSettings_Request\x1a-.CParental_GetSignedParentalSettings_Response\x12\x66\n\x13SetParentalSettings\x12&.CParental_SetParentalSettings_Request\x1a\'.CParental_SetParentalSettings_Response\x12T\n\rValidateToken\x12 .CParental_ValidateToken_Request\x1a!.CParental_ValidateToken_Response\x12]\n\x10ValidatePassword\x12#.CParental_ValidatePassword_Request\x1a$.CParental_ValidatePassword_Response\x12K\n\nLockClient\x12\x1d.CParental_LockClient_Request\x1a\x1e.CParental_LockClient_Response\x12\x66\n\x13RequestRecoveryCode\x12&.CParental_RequestRecoveryCode_Request\x1a\'.CParental_RequestRecoveryCode_Response\x12r\n\x17\x44isableWithRecoveryCode\x12*.CParental_DisableWithRecoveryCode_Request\x1a+.CParental_DisableWithRecoveryCode_Response\x12i\n\x14RequestFeatureAccess\x12\'.CParental_RequestFeatureAccess_Request\x1a(.CParental_RequestFeatureAccess_Response\x12i\n\x14\x41pproveFeatureAccess\x12\'.CParental_ApproveFeatureAccess_Request\x1a(.CParental_ApproveFeatureAccess_Response\x12Z\n\x0fRequestPlaytime\x12\".CParental_RequestPlaytime_Request\x1a#.CParental_RequestPlaytime_Response\x12Z\n\x0f\x41pprovePlaytime\x12\".CParental_ApprovePlaytime_Request\x1a#.CParental_ApprovePlaytime_Response\x12N\n\x0bGetRequests\x12\x1e.CParental_GetRequests_Request\x1a\x1f.CParental_GetRequests_Response\x12r\n\x17ReportPlaytimeAndNotify\x12*.CParental_ReportPlaytimeAndNotify_Request\x1a+.CParental_ReportPlaytimeAndNotify_Response2\xba\x02\n\x0eParentalClient\x12S\n\x14NotifySettingsChange\x12..CParental_ParentalSettingsChange_Notification\x1a\x0b.NoResponse\x12\x43\n\x0cNotifyUnlock\x12&.CParental_ParentalUnlock_Notification\x1a\x0b.NoResponse\x12?\n\nNotifyLock\x12$.CParental_ParentalLock_Notification\x1a\x0b.NoResponse\x12G\n\x12NotifyPlaytimeUsed\x12$.CParental_PlaytimeUsed_Notification\x1a\x0b.NoResponse\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_parental_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _PARENTALCLIENT._options = None
  _PARENTALCLIENT._serialized_options = b'\300\265\030\002'
  _CPARENTAL_ENABLEPARENTALSETTINGS_REQUEST._serialized_start=131
  _CPARENTAL_ENABLEPARENTALSETTINGS_REQUEST._serialized_end=284
  _CPARENTAL_ENABLEPARENTALSETTINGS_RESPONSE._serialized_start=286
  _CPARENTAL_ENABLEPARENTALSETTINGS_RESPONSE._serialized_end=329
  _CPARENTAL_DISABLEPARENTALSETTINGS_REQUEST._serialized_start=331
  _CPARENTAL_DISABLEPARENTALSETTINGS_REQUEST._serialized_end=409
  _CPARENTAL_DISABLEPARENTALSETTINGS_RESPONSE._serialized_start=411
  _CPARENTAL_DISABLEPARENTALSETTINGS_RESPONSE._serialized_end=455
  _CPARENTAL_GETPARENTALSETTINGS_REQUEST._serialized_start=457
  _CPARENTAL_GETPARENTALSETTINGS_REQUEST._serialized_end=513
  _CPARENTAL_GETPARENTALSETTINGS_RESPONSE._serialized_start=515
  _CPARENTAL_GETPARENTALSETTINGS_RESPONSE._serialized_end=592
  _CPARENTAL_GETSIGNEDPARENTALSETTINGS_REQUEST._serialized_start=594
  _CPARENTAL_GETSIGNEDPARENTALSETTINGS_REQUEST._serialized_end=657
  _CPARENTAL_GETSIGNEDPARENTALSETTINGS_RESPONSE._serialized_start=659
  _CPARENTAL_GETSIGNEDPARENTALSETTINGS_RESPONSE._serialized_end=753
  _CPARENTAL_SETPARENTALSETTINGS_REQUEST._serialized_start=756
  _CPARENTAL_SETPARENTALSETTINGS_REQUEST._serialized_end=908
  _CPARENTAL_SETPARENTALSETTINGS_RESPONSE._serialized_start=910
  _CPARENTAL_SETPARENTALSETTINGS_RESPONSE._serialized_end=950
  _CPARENTAL_VALIDATETOKEN_REQUEST._serialized_start=952
  _CPARENTAL_VALIDATETOKEN_REQUEST._serialized_end=1007
  _CPARENTAL_VALIDATETOKEN_RESPONSE._serialized_start=1009
  _CPARENTAL_VALIDATETOKEN_RESPONSE._serialized_end=1043
  _CPARENTAL_VALIDATEPASSWORD_REQUEST._serialized_start=1045
  _CPARENTAL_VALIDATEPASSWORD_REQUEST._serialized_end=1148
  _CPARENTAL_VALIDATEPASSWORD_RESPONSE._serialized_start=1150
  _CPARENTAL_VALIDATEPASSWORD_RESPONSE._serialized_end=1202
  _CPARENTAL_LOCKCLIENT_REQUEST._serialized_start=1204
  _CPARENTAL_LOCKCLIENT_REQUEST._serialized_end=1251
  _CPARENTAL_LOCKCLIENT_RESPONSE._serialized_start=1253
  _CPARENTAL_LOCKCLIENT_RESPONSE._serialized_end=1284
  _CPARENTAL_REQUESTRECOVERYCODE_REQUEST._serialized_start=1286
  _CPARENTAL_REQUESTRECOVERYCODE_REQUEST._serialized_end=1325
  _CPARENTAL_REQUESTRECOVERYCODE_RESPONSE._serialized_start=1327
  _CPARENTAL_REQUESTRECOVERYCODE_RESPONSE._serialized_end=1367
  _CPARENTAL_DISABLEWITHRECOVERYCODE_REQUEST._serialized_start=1369
  _CPARENTAL_DISABLEWITHRECOVERYCODE_REQUEST._serialized_end=1452
  _CPARENTAL_DISABLEWITHRECOVERYCODE_RESPONSE._serialized_start=1454
  _CPARENTAL_DISABLEWITHRECOVERYCODE_RESPONSE._serialized_end=1498
  _CPARENTAL_REQUESTFEATUREACCESS_REQUEST._serialized_start=1500
  _CPARENTAL_REQUESTFEATUREACCESS_REQUEST._serialized_end=1575
  _CPARENTAL_REQUESTFEATUREACCESS_RESPONSE._serialized_start=1577
  _CPARENTAL_REQUESTFEATUREACCESS_RESPONSE._serialized_end=1637
  _CPARENTAL_APPROVEFEATUREACCESS_REQUEST._serialized_start=1640
  _CPARENTAL_APPROVEFEATUREACCESS_REQUEST._serialized_end=1769
  _CPARENTAL_APPROVEFEATUREACCESS_RESPONSE._serialized_start=1771
  _CPARENTAL_APPROVEFEATUREACCESS_RESPONSE._serialized_end=1812
  _CPARENTAL_REQUESTPLAYTIME_REQUEST._serialized_start=1815
  _CPARENTAL_REQUESTPLAYTIME_REQUEST._serialized_end=1950
  _CPARENTAL_REQUESTPLAYTIME_RESPONSE._serialized_start=1952
  _CPARENTAL_REQUESTPLAYTIME_RESPONSE._serialized_end=2007
  _CPARENTAL_APPROVEPLAYTIME_REQUEST._serialized_start=2010
  _CPARENTAL_APPROVEPLAYTIME_REQUEST._serialized_end=2169
  _CPARENTAL_APPROVEPLAYTIME_RESPONSE._serialized_start=2171
  _CPARENTAL_APPROVEPLAYTIME_RESPONSE._serialized_end=2207
  _CPARENTAL_GETREQUESTS_REQUEST._serialized_start=2209
  _CPARENTAL_GETREQUESTS_REQUEST._serialized_end=2300
  _CPARENTAL_GETREQUESTS_RESPONSE._serialized_start=2303
  _CPARENTAL_GETREQUESTS_RESPONSE._serialized_end=2439
  _CPARENTAL_REPORTPLAYTIMEANDNOTIFY_REQUEST._serialized_start=2441
  _CPARENTAL_REPORTPLAYTIMEANDNOTIFY_REQUEST._serialized_end=2544
  _CPARENTAL_REPORTPLAYTIMEANDNOTIFY_RESPONSE._serialized_start=2546
  _CPARENTAL_REPORTPLAYTIMEANDNOTIFY_RESPONSE._serialized_end=2590
  _CPARENTAL_PARENTALSETTINGSCHANGE_NOTIFICATION._serialized_start=2593
  _CPARENTAL_PARENTALSETTINGSCHANGE_NOTIFICATION._serialized_end=2725
  _CPARENTAL_PARENTALUNLOCK_NOTIFICATION._serialized_start=2727
  _CPARENTAL_PARENTALUNLOCK_NOTIFICATION._serialized_end=2803
  _CPARENTAL_PARENTALLOCK_NOTIFICATION._serialized_start=2805
  _CPARENTAL_PARENTALLOCK_NOTIFICATION._serialized_end=2861
  _CPARENTAL_PLAYTIMEUSED_NOTIFICATION._serialized_start=2863
  _CPARENTAL_PLAYTIMEUSED_NOTIFICATION._serialized_end=2943
  _PARENTAL._serialized_start=2946
  _PARENTAL._serialized_end=4587
  _PARENTALCLIENT._serialized_start=4590
  _PARENTALCLIENT._serialized_end=4904
_builder.BuildServices(DESCRIPTOR, 'steammessages_parental_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_remoteclient.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_remoteclient_discovery_pb2 as steammessages__remoteclient__discovery__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n steammessages_remoteclient.proto\x1a\x18steammessages_base.proto\x1a*steammessages_remoteclient_discovery.proto\"r\n\x16\x43MsgRemoteClientStatus\x12\x11\n\tclient_id\x18\x01 \x01(\x04\x12\x13\n\x0binstance_id\x18\x02 \x01(\x04\x12\x30\n\x06status\x18\x03 \x01(\x0b\x32 .CMsgRemoteClientBroadcastStatus\"\xe4\x04\n\x19\x43MsgRemoteClientAppStatus\x12<\n\x0estatus_updates\x18\x01 \x03(\x0b\x32$.CMsgRemoteClientAppStatus.AppStatus\x1a\xe8\x01\n\rAppUpdateInfo\x12\x19\n\x11time_update_start\x18\x01 \x01(\x07\x12\x19\n\x11\x62ytes_to_download\x18\x02 \x01(\x04\x12\x18\n\x10\x62ytes_downloaded\x18\x03 \x01(\x04\x12\x18\n\x10\x62ytes_to_process\x18\x04 \x01(\x04\x12\x17\n\x0f\x62ytes_processed\x18\x05 \x01(\x04\x12\'\n\x1b\x65stimated_seconds_remaining\x18\x06 \x01(\x05:\x02-1\x12\x15\n\rupdate_result\x18\x07 \x01(\x05\x12\x14\n\x0cupdate_state\x18\x08 \x01(\r\x1aO\n\x0cShortcutInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x12\n\ncategories\x18\x03 \x03(\t\x12\x0f\n\x07\x65xepath\x18\x04 \x01(\t\x1a\xcc\x01\n\tAppStatus\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tapp_state\x18\x02 \x01(\r\x12=\n\x0bupdate_info\x18\x03 \x01(\x0b\x32(.CMsgRemoteClientAppStatus.AppUpdateInfo\x12>\n\rshortcut_info\x18\x04 \x01(\x0b\x32\'.CMsgRemoteClientAppStatus.ShortcutInfo\x12\x1d\n\x0fvr_not_required\x18\x05 \x01(\x08:\x04true\"\xc9\x03\n\x1b\x43MsgRemoteClientStartStream\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x13\n\x0b\x65nvironment\x18\x02 \x01(\x05\x12\x15\n\rgamepad_count\x18\x03 \x01(\x05\x12\x19\n\rlaunch_option\x18\x04 \x01(\x05:\x02-1\x12!\n\x12lock_parental_lock\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x14unlock_parental_lock\x18\x06 \x01(\t\x12\x1c\n\x14maximum_resolution_x\x18\x07 \x01(\x05\x12\x1c\n\x14maximum_resolution_y\x18\x08 \x01(\x05\x12>\n\x08gamepads\x18\t \x03(\x0b\x32,.CMsgRemoteClientStartStream.ReservedGamepad\x12\x1e\n\x13\x61udio_channel_count\x18\n \x01(\x05:\x01\x32\x12.\n\x13supported_transport\x18\x0b \x03(\x0e\x32\x11.EStreamTransport\x1a\x46\n\x0fReservedGamepad\x12\x17\n\x0f\x63ontroller_type\x18\x01 \x01(\r\x12\x1a\n\x12\x63ontroller_subtype\x18\x02 \x01(\r\"\xdb\x02\n#CMsgRemoteClientStartStreamResponse\x12\x1a\n\x0f\x65_launch_result\x18\x01 \x01(\x05:\x01\x32\x12\x13\n\x0bstream_port\x18\x02 \x01(\r\x12\x16\n\x0elaunch_options\x18\x03 \x03(\x05\x12\x12\n\nauth_token\x18\x04 \x01(\x0c\x12;\n\ttransport\x18\x05 \x01(\x0e\x32\x11.EStreamTransport:\x15k_EStreamTransportUDP\x12\x14\n\x0crelay_server\x18\x06 \x01(\t\x12\x13\n\x0blaunch_task\x18\x07 \x01(\t\x12\x1a\n\x12launch_task_detail\x18\x08 \x01(\t\x12\x19\n\x11launch_tasks_done\x18\t \x01(\x05\x12\x1a\n\x12launch_tasks_total\x18\n \x01(\x05\x12\x1c\n\x14vr_connection_params\x18\x0b \x01(\t\"\x16\n\x14\x43MsgRemoteClientPing\"\x1e\n\x1c\x43MsgRemoteClientPingResponse\"S\n\x1a\x43MsgRemoteClientAcceptEULA\x12\x0e\n\x06\x61pp_id\x18\x01 \x03(\r\x12\x0f\n\x07\x65ula_id\x18\x02 \x03(\t\x12\x14\n\x0c\x65ula_version\x18\x03 \x03(\r\"O\n#CMsgRemoteClientGetControllerConfig\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x18\n\x10\x63ontroller_index\x18\x03 \x01(\r\"U\n+CMsgRemoteClientGetControllerConfigResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x12\n\nconfig_vdf\x18\x02 \x01(\x0c\"3\n CMsgRemoteClientStreamingEnabled\x12\x0f\n\x07\x65nabled\x18\x01 \x02(\x08\"L\n\x1c\x43MsgRemoteClientWifiAPStatus\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04wpa2\x18\x03 \x01(\x08\x42\x05H\x01\x90\x01\x00')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_remoteclient_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\000'
  _CMSGREMOTECLIENTSTATUS._serialized_start=106
  _CMSGREMOTECLIENTSTATUS._serialized_end=220
  _CMSGREMOTECLIENTAPPSTATUS._serialized_start=223
  _CMSGREMOTECLIENTAPPSTATUS._serialized_end=835
  _CMSGREMOTECLIENTAPPSTATUS_APPUPDATEINFO._serialized_start=315
  _CMSGREMOTECLIENTAPPSTATUS_APPUPDATEINFO._serialized_end=547
  _CMSGREMOTECLIENTAPPSTATUS_SHORTCUTINFO._serialized_start=549
  _CMSGREMOTECLIENTAPPSTATUS_SHORTCUTINFO._serialized_end=628
  _CMSGREMOTECLIENTAPPSTATUS_APPSTATUS._serialized_start=631
  _CMSGREMOTECLIENTAPPSTATUS_APPSTATUS._serialized_end=835
  _CMSGREMOTECLIENTSTARTSTREAM._serialized_start=838
  _CMSGREMOTECLIENTSTARTSTREAM._serialized_end=1295
  _CMSGREMOTECLIENTSTARTSTREAM_RESERVEDGAMEPAD._serialized_start=1225
  _CMSGREMOTECLIENTSTARTSTREAM_RESERVEDGAMEPAD._serialized_end=1295
  _CMSGREMOTECLIENTSTARTSTREAMRESPONSE._serialized_start=1298
  _CMSGREMOTECLIENTSTARTSTREAMRESPONSE._serialized_end=1645
  _CMSGREMOTECLIENTPING._serialized_start=1647
  _CMSGREMOTECLIENTPING._serialized_end=1669
  _CMSGREMOTECLIENTPINGRESPONSE._serialized_start=1671
  _CMSGREMOTECLIENTPINGRESPONSE._serialized_end=1701
  _CMSGREMOTECLIENTACCEPTEULA._serialized_start=1703
  _CMSGREMOTECLIENTACCEPTEULA._serialized_end=1786
  _CMSGREMOTECLIENTGETCONTROLLERCONFIG._serialized_start=1788
  _CMSGREMOTECLIENTGETCONTROLLERCONFIG._serialized_end=1867
  _CMSGREMOTECLIENTGETCONTROLLERCONFIGRESPONSE._serialized_start=1869
  _CMSGREMOTECLIENTGETCONTROLLERCONFIGRESPONSE._serialized_end=1954
  _CMSGREMOTECLIENTSTREAMINGENABLED._serialized_start=1956
  _CMSGREMOTECLIENTSTREAMINGENABLED._serialized_end=2007
  _CMSGREMOTECLIENTWIFIAPSTATUS._serialized_start=2009
  _CMSGREMOTECLIENTWIFIAPSTATUS._serialized_end=2085
# @@protoc_insertion_point(module_scope)
